/*				
	Project:			Tax Administration vs. Tax Rates: Evidence from Corporate Taxation in Indonesia
				
	Authors:			M. Chatib Basri
						Mayara Felix
						Rema Hanna
						Benjamin Olken
					
	Note:
		- This file executes the Stata .do files that clean and analyze
		  confidential anonymized taxpayer data provided by 
		  Indonesia's Directorate General of Taxes.
		  
		- Code Plot_ETI_variation.R should be run in R anytime after
		  the .do file 5_1_ETI_estimation_main.do has been run in Stata

*/
version 14.2	
clear all
set more off


***********************************************
************** I. Set paths ******************
***********************************************
 
	global raw 		""	/* Path where anonymized raw files received from DGT are located */
	global output 	""	/* Path to where output files will be saved */
	global dofile	""  /* Path to where all .do files are saved */
	
**************************************************
************ II. Installed packages **************
**************************************************

* Add .ado path to system path where provided .ado files are located
	adopath + "${dofile}/ado/"

/*	This is the list of all installed packages and their respective versions.
	We provide the exact .ado files and corresponding helpfiles for ease
	
	Package		Version number	Version date
	
	binscatter	7.02			24-Nov-13
	ebalance	1.5.4			29-Jan-15
	gtools		1.0.1 			23-Jul-18
	ivreg2		4.1.10  		9-Feb-16
	ivreghdfe	1.0.0  			7-Jul-18
	reghdfe 	5.7.3 			13-Nov-19
	renvars		2.4.0  			22-Aug-05
	rforest		1.7.2			Mar-20
	unique		1.2.2   		10-Nov-17
	
*/

***********************************************
************ II. Create subfolders ************
***********************************************
	
	cap mkdir "${output}/temp_data/"
	cap mkdir "${output}/analysis/"
	cap mkdir "${output}/analysis/csv/"
	cap mkdir "${output}/analysis/outreg/"
	cap mkdir "${output}/analysis/graphs/"
	cap mkdir "${output}/analysis/regcoeffs/"
	
******************************************
************ I. Run .do files ************
******************************************

* Auxiliary files
 do "${dofile}/prep/0_0_import_map_and_kpp_codes.do"

* Clean raw data
 do "${dofile}/prep/0_1_clean_SIDJP.do"
 do "${dofile}/prep/0_2_clean_MPN.do"
 do "${dofile}/prep/0_3_clean_AUDIT.do"
 do "${dofile}/prep/0_4_clean_STPSKPKB_PPN.do"

* Process anonymized raw DGT staff and budget data
 do "${dofile}/prep/0_5_clean_SIKKA.do"
 do "${dofile}/prep/0_6_SIKKA_panels.do"
 do "${dofile}/prep/0_7_SIKKA_compile_salary_schedules.do"
 do "${dofile}/prep/0_8_map_npwp_to_industry_codes.do"

* Create analysis dataset combining treatment and outcomes data
 do "${dofile}/analysis/1_1_Define_treatment_calendar_yr.do"
 do "${dofile}/analysis/1_2_Eligible_taxpayers_selection_yr.do"
 do "${dofile}/analysis/1_3_Analysis_file_calendar_yr.do"
 do "${dofile}/analysis/1_4_Extract_SPT_1771_corrections.do"
 do "${dofile}/analysis/1_5_Extract_taxpayer_employment.do"
 do "${dofile}/analysis/1_6_Extract_KPP_staffing.do"
 do "${dofile}/analysis/1_7_Extract_calendar_payments.do"

* Create weights to balance treated and control taxpayers on pre-treatment selection criteria
 do "${dofile}/analysis/2_1_Balancing_weights_main.do"
 do "${dofile}/analysis/2_2_Balancing_weights_robustness_dont_drop_100mil.do"
 do "${dofile}/analysis/2_3_Balancing_weights_robustness_comm_support_99_1.do"
 do "${dofile}/analysis/2_4_Balancing_weights_robustness_add20056.do"
 do "${dofile}/analysis/2_5_Balancing_weights_robustness_random_forest.do"
 do "${dofile}/analysis/2_6_Balancing_weights_robustness_placebo.do"

* MTO effect Diff-in-Diff regressions and robustness
 do "${dofile}/analysis/3_1_MTO_WDD_regressions_main.do"
 do "${dofile}/analysis/3_2_MTO_WDD_regressions_robustness_dont_drop_100mil.do"
 do "${dofile}/analysis/3_3_MTO_WDD_regressions_robustness_comm_support_99_1.do"
 do "${dofile}/analysis/3_4_MTO_WDD_regressions_robustness_add20056.do"
 do "${dofile}/analysis/3_5_MTO_WDD_regressions_robustness_random_forest.do"
 do "${dofile}/analysis/3_6_MTO_WDD_regressions_robustness_placebo.do"
 do "${dofile}/analysis/3_7_MTO_WDD_regressions_robustness_large_small_PTOs.do"
 do "${dofile}/analysis/3_8_MTO_WDD_regressions_robustness_2003_2009.do"
 do "${dofile}/analysis/3_9_MTO_WDD_regressions_robustness_by_baseline_size.do"
 
* MTO mechanisms analysis
 do "${dofile}/analysis/4_1_Probability_of_assessment.do"
 do "${dofile}/analysis/4_2_Probability_of_audit.do"

* ETI estimation, robustness, and regression of additional outcomes on Marginal Tax Rate (MTR)
 do "${dofile}/analysis/5_1_ETI_estimation_main.do"
 do "${dofile}/analysis/5_2_ETI_estimation_robustness_2008_2010_difference.do"
 do "${dofile}/analysis/5_3_ETI_trend_graphs.do"
 
* Counterfactual exercise

 do "${dofile}/analysis/6_1_Stats_for_counterfactual.do"
 do "${dofile}/analysis/6_2_Counterfactual.do"

* Budget and descriptive stats on all taxpayers
 do "${dofile}/analysis/7_Budget.do"
 do "${dofile}/analysis/8_Descriptive_statistics_all_taxpayers.do"
 do "${dofile}/analysis/9_Penalties.do"

 clear all
