* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_1_Balancing_weights_main.log", replace
di in red "Running 2_1_Balancing_weights_main.do"

**********************************
*** 0.1 Define locals/globals ****
**********************************

* Toggles that switch different parts of the code on and off
local setup				= 1		/* Reshapes wide SPT 1771 + MPN data for all eligible on long, documents sample selection */
local weights			= 1		/* Manual cleaning of variables and weights estimation */
local dist				= 1		/* Plot joint distribution */

matrix obs 	= J(10,4,.) /* Matrix to store observations kept in sample selection */

global minyear 	= 2003
global maxyear 	= 2011

***************************************************************************
***************** II. Data setup and analysis begin here ******************
***************************************************************************

************************************
***** 1. Set up analysis file ******
************************************

if `setup'==1{
	
	u "${output}/analysis/MTO_analysisfile_calendar_yr.dta", clear
	
	* Discard taxpayers that were eligible for MTOs selecting in 2006
	foreach y in 2006 2007 2008{
		gen select`y' = (selection_yr==`y')
		bys npwp: egen elig`y' = max(select`y')
	}
	
	keep if (elig2007==1 | elig2008==0) & elig2006==0
	drop select20* elig20*
	
	* Keep MTOs created in 2007 (this drops Jakarta Pusat and Bekasi, created in 2004 and 2006)
	keep if inlist(selection_mto,725, 441, 38, 62, 7, 46, 812, 651, 123, 308, 511, 641, 631)
	
	* Keep selection years 2007 and 2008
	keep if inlist(selection_yr,2007,2008)
	
	* Discard taxpayers eligible for selection at multiple MTOs
	qui unique selection_mto, by(npwp) gen(d)
	bys npwp: egen m = max(d)
	drop if m>1
	
	* 2008 expansiom is only important for Jakarta Barat (38). Keep 2008 expansion for that MTO
	drop if selection_yr==2007 & selection_mto==38
	drop if selection_yr==2008 & selection_mto!=38
		
	* Make sure origin_kpp never missing
	misstable sum bcy*_kpp
	
	foreach i in 5 4 3 2{
		replace origin_kpp = bcy`i'_kpp if missing(origin_kpp)
	}
	
	assert !missing(origin_kpp)
	
	* Keep calendear years 2003-2011 (ocy0 = 2007 or 2008)
	drop bcy6* bcy7* bcy8* bcy9* ///
		 ocy5* ocy6* ocy7* ocy8* 
	
	tab selection_mto
	
	* Fill in in-between years of observed treatment
	* If year x is missing, assign treatment status in year x to the treatment status of year x+1
	* br npwp selection_yr bcy*_mto ocy*_mto 

	* Outcome years
	/*
		Replace 2007-2010 with 2008-2011 for selection year 2007
		Replace 2008-2010 with 2009-2011 for selection year 2008
	*/
	
	foreach i in 3 2 1 0{
		local o = `i' + 1
		replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2007
	}
	
	foreach i in 2 1 0{
		local o = `i' + 1
		replace ocy`i'_mto = ocy`o'_mto if missing(ocy`i'_mto) & selection_yr==2008
	}
	
	* Baseline years 
	/*
		Replace 2004-2006 with 2003-2005 for selection year 2007
		Replace 2004-2007 with 2003-2006 for selection year 2008
	*/
	
	foreach i in 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2007
	}
	
	foreach i in 4 3 2 1{
		local b = `i' +1
		replace bcy`i'_mto = bcy`b'_mto if missing(bcy`i'_mto) & selection_yr==2008
	}
	
	******************** Ever MTO treatment ********************
	forvalues i=0/4{
		replace ocy`i'_mto_post = 1 if ocy`i'_mto== 1 & missing(ocy`i'_mto_post)
		replace ocy`i'_mto_post = 0 if ocy`i'_mto== 0 & missing(ocy`i'_mto_post)
	}
	
	* 2007 selection
	egen inMTOby2008_07 = rowmax(ocy0_mto_post ocy1_mto_post) if selection_yr==2007
	egen inMTOby2009_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post) if selection_yr==2007
	egen inMTOby2010_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post) if selection_yr==2007
	egen inMTOby2011_07 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post ocy4_mto_post) if selection_yr==2007
	
	* 2008 selection
	egen inMTOby2008_08 = rowmax(ocy0_mto_post) if selection_yr==2008
	egen inMTOby2009_08 = rowmax(ocy0_mto_post ocy1_mto_post) if selection_yr==2008
	egen inMTOby2010_08 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post) if selection_yr==2008
	egen inMTOby2011_08 = rowmax(ocy0_mto_post ocy1_mto_post ocy2_mto_post ocy3_mto_post) if selection_yr==2008
	
	forvalues y=2008/2011{
		gen inMTOby`y' = inMTOby`y'_07
		replace inMTOby`y' = inMTOby`y'_08 if selection_yr==2008
	}
	
	egen inMTOby2007 = rowmax(ocy0_mto_post) if selection_yr==2007
	replace inMTOby2007 = 0 if selection_yr==2008

	drop *_07 *_08
	
	* Ever in a pre-2007 MTO
	forvalues i=1/5{
		replace bcy`i'_mto_post = 1 if bcy`i'_mto== 1 & missing(bcy`i'_mto_post)
		replace bcy`i'_mto_post = 0 if bcy`i'_mto== 0 & missing(bcy`i'_mto_post)
	}
	
	* Ever in a pre-2007 MTO
	egen double mtopre  = rowmax(bcy*_mto_post)

	** Merge KLU code: fixed for taxpayer over time
	merge m:1 npwp using "${output}/analysis/npwp_klu_mapping.dta", keepusing(klu_1721)
	keep if _merge==1 | _merge==3
	drop _merge
	
	tostring klu_1721, gen(klu2)
	replace klu2 = substr(klu2,1,2)
	destring klu2, gen(k)
	drop klu2
	ren k klu2
	
	replace klu2 = 99 if klu2==.

	replace klu_1721 = 99999 if klu_1721==.
	
	tab klu2
	
	********** Sample restriction accounting **********
	
	* All taxpayers
	unique npwp
	mat obs[1,1] = r(unique)
	unique npwp if inMTOby2008==1
	mat obs[1,2] = r(unique)
	
	* Has well defined MTO status (filed any SPT 1771 in 2007-2011)
	keep if !missing(inMTOby2008)

	unique npwp
	mat obs[2,1] = r(unique)
	unique npwp if inMTOby2008==1
	mat obs[2,2] = r(unique)
	
	* Drop if in a pre-2007 MTO any time before 2007 selection year
	drop if mtopre==1

	unique npwp
	mat obs[3,1] = r(unique)
	unique npwp if inMTOby2008==1
	mat obs[3,2] = r(unique)
	
	* 2003-5 gross income > 100 million Rp (10,000 USD at 2007 exchange ratio)
	forvalues i=2/4{
		drop if bcy`i'_gincome < 10^8 	& 	selection_yr==2007
		
		local j = `i'-1
		drop if bcy`j'_gincome < 10^8 	& 	selection_yr==2008
	}
	
	unique npwp
	mat obs[4,1] = r(unique)
	unique npwp if inMTOby2008==1
	mat obs[4,2] = r(unique)
	
	* Some names are too long - rename
	renvars *ppH_2529_corporate, subst("corporate" "corp")
	renvars *ppH_2529_individual, subst("individual" "ind")
	renvars *pp*domestic, subst("domestic" "dom")
	renvars *pp*import, subst("import" "imp")
	
	*******************************************
	********** Reshape long on year ***********
	*******************************************
	
	gen double bcy1_kpp = origin_kpp
	keep npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721 
	order npwp selection_yr selection_mto inMTOby* origin_kpp bcy* ocy*  klu2 klu_1721
	
	preserve
		keep if _n==1
		keep bcy1*
		renvars _all, predrop(5)
		
		ds _all, v(32)
		local prepostvars = "`r(varlist)'"
	restore
	
	foreach x in `prepostvars'{
		renvars *y?*_`x', pref(`x')
		renvars *y?_`x', subst("_`x'" "")
	}

	qui reshape long `prepostvars' , ///
			i(npwp selection_yr) ///
			j(year) string
	
	* Recode year
	split year, parse("y")
	destring year2, replace
	drop year 
	gen double year = .
	replace year = selection_yr - year2 if year1=="bc"
	replace year = selection_yr + year2 if year1=="oc"
	drop year1 year2
	
	** Years restriction **
	keep if year>=${minyear} & year<=${maxyear}

	preserve
		clear
		svmat obs
		ren obs1 all
		ren obs2 all_inMTOby2008
		outsheet using "${output}/analysis/csv/MTO_sample_selection_breakdown_${minyear}_${maxyear}.csv", comma replace
	restore
		
	drop mto_post
	order npwp year kpp mto inMTOby2008 selection*
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", replace
}


******************************************************
******* 2. Manual cleaning and matching weights ******
******************************************************

if `weights'==1{
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", clear
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year inMTOby* ///
	   kpp mto origin_kpp ontime corrected correction  klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	gen evermto = inMTOby2008
	do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"		/* This drops obs if outlier or SPT 1771 incorrect filing issues */
	
	drop p9999* p0001* istop* isbot*
	drop evermto

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year origin_kpp inMTOby2008 kpp mto 
	
	tempfile main
	sa `main'
	
	*************************************************************************
	****** Graphs of 2005 and 2011 gross income and taxes paid **************
	*************************************************************************
	
	keep if year==2005 | year==2011
	gen double lngincome = ln(gincome*10^9)
	gen double lnppHN_total = ln(ppHN_total*10^9)
	
	foreach year in 2005 2011{
	foreach x in lngincome lnppHN_total{
		local lngincome "Log(`year' Gross income)"
		local lnppHN_total "Log(`year' Total taxes paid)"
	
		twoway hist `x' if year==`year', color(gs8%25) scheme(s1mono) xtitle(``x'')   ///
		percent 
		graph export "${output}/analysis/graphs/histogram_`x'_`year'.pdf", replace
		}
	}
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `main', clear
	
	* Keep treatment and baseline data
	keep npwp year inMTOby2008 selection_mto selection_yr gincome ppHN_total tincome
	
	* Match 2008 Jakarta Barat selection using 2005 data
	replace selection_yr = 2007 if selection_yr==2008
	
	keep if inrange(year,2003,2005)
	
	* Note: since now restriction is that payments and filings be paid or filed
	* 		by June of following tax year, all data in the setup file has
	*		2003-2005 payment and filing dates prior to selection date
	
	gen double base =.
	replace base = selection_yr - year
	drop year
	
	reshape wide gincome ppHN_total tincome, i(npwp inMTOby2008 selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************

	forvalues base=2/4{
	
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)		// 3 Rows: 99, 1, intersection
			
			forvalues i=0/1{
				qui egen double p975`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(97.5)
				qui egen double p025`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(2.5)
				
				qui sum p975`var'`i'
				local p975`var'`i' = `r(mean)'
				
				qui sum p025`var'`i'
				local p025`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p025`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p975`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p025`var'1',`p025`var'0')
			mat support`base'`var'[3, 2]  = min(`p975`var'1',`p975`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = 2007-`base'
				ren support`base'`var'1 p025
				ren support`base'`var'2 p975
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p025 p975
				order var baseyear mto  p025 p975 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p975* p025*
	}
	
	* Collect all matrices
	preserve
		u `s2gincome', clear
		append using `s2ppHN_total'
		forvalues base=3/4{
			foreach var in gincome ppHN_total{
				append using `s`base'`var''
			}
		}
		
		saveold "${output}/analysis/regcoeffs/MTO_match_common_support_numbers.dta", replace
	restore
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
							
	gen double comsup23 = 	comsup2==1 & ///
							( gincome3 > lbgincome3 & gincome3< ubgincome3 ) & ///
							( ppHN_total3 > lbppHN_total3 & ppHN_total3 < ubppHN_total3 ) & ///
							!missing(gincome3) & !missing(ppHN_total3)
	
	gen double comsup24 = comsup23 == 1 & ///
							( gincome4 > lbgincome4 & gincome4 < ubgincome4) & ///
							( ppHN_total4 > lbppHN_total4 & ppHN_total4 < ubppHN_total4) & ///
							!missing(gincome4) & !missing(ppHN_total4)
	
	
	* For graphs - log lower and upper bounds ib billions)
	foreach var of varlist  lbgincome2 ubgincome2 lbppHN_total2 ubppHN_total2{
		replace `var' = ln(`var'*10^9)
	}
	
	levelsof lbgincome2, local(lbgincome2)
	levelsof ubgincome2, local(ubgincome2)
	levelsof lbppHN_total2, local(lbppHN_total2)
	levelsof ubppHN_total2, local(ubppHN_total2)
	
	drop lb* ub*
	
	local support_graphs = 1
	if `support_graphs'==1{
		
		gen double lngincome2 = ln(gincome2*10^9)
		gen double lnppHN_total2 = ln(ppHN_total2*10^9)
		gen double lntincome2 = ln(tincome2*10^9)
		
		label var lngincome2 "2005 Log gross income"
		label var lnppHN_total2 "2005 Log total taxes paid"
		
		* Common support graphs 
		kdensity lngincome2 if inMTOby2008==1, color(gs3%30) recast(area) ///
		addplot(kdensity  lngincome2 if inMTOby2008==0 , color(gs10%30) recast(area)) ///
		legend(label(1 "In first MTO cohort") label(2 "Not in first MTO cohort") rows(1)) scheme(s1mono) title("") ///
		xline(`lbgincome2', lcolor(black) lwidth(thick) lpattern(dash)) xline(`ubgincome2', lcolor(black) lwidth(thick) lpattern(dash))
		graph export "${output}/analysis/graphs/kdensity_lngincome_2005.pdf", replace
		
		kdensity lnppHN_total2 if inMTOby2008==1, color(gs3%30) recast(area) ///
		addplot(kdensity lnppHN_total2 if inMTOby2008==0 , color(gs10%30) recast(area)) ///
		legend(label(1 "In first MTO cohort") label(2 "Not in first MTO cohort") rows(1)) scheme(s1mono) title("") ///
		xline(`lbppHN_total2', lcolor(black) lwidth(thick) lpattern(dash)) xline(`ubppHN_total2', lcolor(black) lwidth(thick) lpattern(dash))
		graph export "${output}/analysis/graphs/kdensity_lnppHN_total_2005.pdf", replace

		* Probability of MTO as function of gross income and total taxes paid
		* Do these as binscatter
		
		binscatter inMTOby2008 lngincome2, genxq(bin_lngincome2) ///
		scheme(s1color) color(gs8) title("") ///
		ytitle("Probability of 2007 MTO assignment")  yscale(titlegap(*5)) ///
		xtitle("2005 Log gross income")  nquantiles(40) legend(off) linetype(none)
		graph export "${output}/analysis/graphs/ProbMTO_lngincome2005.pdf", replace

		binscatter inMTOby2008 lnppHN_total2, genxq(bin_lnppHN_total2) ///
		scheme(s1color) color(gs8) title("") ///
		ytitle("Probability of 2007 MTO assignment")  yscale(titlegap(*5)) ///
		xtitle("2005 Log total taxes paid")  nquantiles(40) legend(off) linetype(none)
		graph export "${output}/analysis/graphs/ProbMTO_lnppHN_total2005.pdf", replace
		
		preserve
			keep npwp bin*
			gduplicates drop
			saveold "${output}/analysis/regcoeffs/MTO_input_variable_bins_genxq.dta", replace
		restore
		
		* Drop vars that won't be used for clarity
		drop tincome* ln*
	}
	
	******************* Entropy balancing weights *******************
	
	* Selection MTO 
	qui tab selection_mto, gen(fe_r)
	
	* 2003-5 entropy weights	(base 2-4)
	ebalance inMTOby2008 gincome2 gincome4 gincome3  ///
					 ppHN_total2 ppHN_total4 ppHN_total3 fe_r* if comsup24==1, ///
	targets(1) generate(eweight24)
	
	* 2005 entropy weights		(base 2)
	ebalance inMTOby2008 gincome2  ///
					 ppHN_total2 fe_r* if comsup2==1, ///
	targets(1) generate(eweight2)  
	
	preserve
		keep npwp eweight*
		
		tempfile eweights
		sa `eweights'
	restore
	
	*********************************************************
	********************* Logit weights *********************
	*********************************************************
	
	* Do splines in levels not in logs
	foreach var of varlist gincome* ppHN_total*{
		mkspline spline`var' 3 = `var', pctile marginal
	}
	
	* Interaction
	forvalues y=2/4{
		gen double interaction`y' = gincome`y'*ppHN_total`y'
	}
	
	* Drop KPP Madya Medan 
	tab selection_mto
	sum fe_r* if selection_mto==123
	drop fe_r5
	
	* 2005-3 weights (base 2-4)
	logit inMTOby2008 spline*2? spline*3? spline*4?  ///
				  interaction2 interaction3 interaction4 fe_r*   if comsup24 == 1
	
	qui predict phat24 if e(sample), pr
	qui predict se24 if e(sample), stdp
	
	replace phat24 = round(phat24,0.001)
	gen double w24 = cond(inMTOby2008==1,1/phat24,1/(1-phat24))
	
	* 2005 predictors (base 2)
	logit inMTOby2008 spline*2? interaction2 fe_r*	if comsup2 == 1
		
	qui predict phat2 if e(sample), pr
	qui predict se2 if e(sample), stdp
	
	replace phat2 = round(phat2,0.001)
	gen double w2 = cond(inMTOby2008==1,1/phat2,1/(1-phat2))
	
	sum w2 if inMTOby2008==1, detail
	sum w24 if inMTOby2008==1, detail
	
	* Drop top 1% largest weights within each treatment group
	foreach x in 24 2{
		qui sum w`x' if inMTOby2008==1, detail
		qui replace w`x'=. if w`x' > `r(p99)' & inMTOby2008==1
		
		qui sum w`x' if inMTOby2008==0, detail
		qui replace w`x'=. if w`x' > `r(p99)' & inMTOby2008==0
	}
	
	preserve
		keep npwp phat* w*
		tempfile phat
		sa `phat'
	restore
	
	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************
	
	u `main', clear
	merge m:1 npwp using `eweights'
	keep if _merge==1 | _merge==3
	drop _merge
	
	merge m:1 npwp using `phat'
	keep if _merge==1 | _merge==3
	drop _merge

	*******************************************************************
	*************************** Diagnostics ***************************
	*******************************************************************
	ds _all, v(32)
	
	ds npwp selection_yr selection_mto origin_kpp inMTOby2008 kpp mto year klu* w* phat* eweight*, not
	local vars "`r(varlist)'"
	
	order npwp selection* year origin_kpp inMTOby2008 kpp mto klu*  phat* w? w?? eweight*
	
	order pp*_total ppH* ppN* correction corrected ontime, last
	
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_weights.dta", replace	
}

************************************************
******* 3. Joint distribution scatterplot ******
************************************************

if `dist'==1{

	/* Lower and upper bounds for graphs */
	u "${output}/analysis/regcoeffs/MTO_match_common_support_numbers.dta", clear
	keep if mto==. & baseyear==2005

	gen double lb = ln(p025*10^9)
	gen double ub = ln(p975*10^9)
	
	keep var lb ub
	replace var = "ginc" if var=="gincome"
	replace var = "pay" if var=="ppHN_total"
	
	levelsof lb if var=="ginc", local(lbginc)
	levelsof lb if var=="pay", local(lbpay)
	
	levelsof ub if var=="ginc", local(ubginc)
	levelsof ub if var=="pay", local(ubpay)

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
	
	keep if year==2005  
	assert !missing(inMTOby2008)
	keep npwp eweight2 inMTOby2008 ppHN_total gincome
	
	* Back to total ruppes instead of billions
	replace ppHN_total=ppHN_total*10^9
	replace gincome= gincome*10^9
	gen double lnppHN_total = ln(ppHN_total)
	gen double lngincome = ln(gincome)
	
	keep if !missing(lnppHN_total) & !missing(lngincome)
	
	********* Main bounds ************

	twoway 	(scatter  lnppHN_total lngincome ///
					 if inMTOby2008==0, mcolor(red%15) msymbol(O) msize(small) mlcolor(none)) ///
			(scatter  lnppHN_total lngincome ///
					 if inMTOby2008==1, mcolor(blue%30) msymbol(O) msize(small) mlcolor(none)),  ///
			yline(`lbpay' `ubpay', lcolor(black) lpattern(dash) ) ///
			xline(`lbginc' `ubginc', lcolor(black) lpattern(dash)) ///
			scheme(s1mono) legend(order(2 1) label(2 "MTO") label(1 "Not MTO")) ///
			ytitle("Log(2005) total taxes paid") ///
			xtitle("Log(2005) gross income")
	
	graph export "${output}/analysis/graphs/main_bounds_2_dim.pdf", replace	

}
clear
log close
