* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/2_5_Balancing_weights_robustness_random_forest.log", replace
di in red "Run 2_5_Balancing_weights_robustness_random_forest.do"

global minyear 	= 2003
global maxyear 	= 2011


u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", clear

* Express Rp variables in billion Rp
ds npwp selection_yr selection_mto year inMTOby* ///
   kpp mto origin_kpp ontime corrected correction klu2 klu_1721, not

di "`r(varlist)'"
foreach var of varlist `r(varlist)'{
	replace `var' = `var'/10^9
}

* Summarize SPT 1771 after cleaning so we see what this looks like
gen evermto = inMTOby2008
do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"		/* This drops obs if outlier or SPT 1771 incorrect filing issues */

drop p9999* p0001* istop* isbot*
drop evermto

* Make aggregate variables
egen double ppH_total = rowtotal(ppH*)
egen double ppN_total = rowtotal(ppN*)
gen double  ppHN_total = ppH_total + ppN_total

order npwp selection_yr selection_mto year origin_kpp inMTOby2008 kpp mto 

****************************************************************************
****************************** Merge additional data ***********************
****************************************************************************

* CIT refund
gen double refund = -paidvalue if paidvalue <0
replace refund = 0 if missing(refund)

****************************************
**** Merge additional payment measures *
****************************************
* Already in billions. Replace with zero if missing (note won't affect ppH_total, ppN_total, ppHN_total)
misstable sum  ppH* ppN*
foreach var of varlist ppH* ppN*{
	replace `var' = 0 if missing(`var')
}

* Dollars in the door
merge 1:1 npwp year using "${output}/analysis/calendar_tax_payments.dta"
keep if _merge==1 | _merge==3
drop _merge

* Previously was double-counting payments!! How is it possible?
egen double allpay = rowtotal(allpay_*)
egen double allpay_preDec = rowtotal(allpaypreDec_*)

* Late payments (past 6 months after the end of tax year)
merge 1:1 npwp year using "${output}/analysis/late_tax_payments.dta"
keep if _merge==1 | _merge==3
drop _merge

egen double latepay = rowtotal(latepay*)

*******************************
*** Merge corrections data ****
*******************************
cap drop tax_yr
cap drop correction corrected
foreach type in filing tax{
	ren year `type'_yr
	merge 1:1 npwp `type'_yr using "${output}/analysis/SPT_1771_anycorr_`type'_yr.dta"
	keep if _merge==1 | _merge==3
	replace anycorr_`type'_yr = 0 if missing(anycorr_`type'_yr)
	drop _merge
	ren `type'_yr year
}

* Recoveries from corrections - already in billions
ren year correction_yr
merge 1:1 npwp correction_yr using "${output}/analysis/SPT_1771_correction_totals.dta", ///
keepusing(tot_corr_gincome tot_corr_tincome tot_corr_totcitdue)
keep if _merge==1 | _merge==3
drop _merge
ren correction_yr year

foreach var of varlist tot_corr_gincome tot_corr_tincome tot_corr_totcitdue{
	replace `var' = 0 if missing(`var')
}

*********************************************
*********** Merge assessment data ***********
*********************************************
preserve
	// NPWPs in analysis file
	keep npwp
	duplicates drop
	tempfile npwps
	sa `npwps'

	// Get enforcement data - for now just dummies of each type of letter
	u "${output}/analysis/stpskp_ppn_all_clean.dta", clear
	destring npwp, replace force
	format npwp %15.0g
	
	merge m:1 npwp using `npwps'
	keep if _merge==3
	drop _merge
	
	keep npwp *_dt appeal_dt assessment_type
	
	* Shorten names
	renvars *_letter_dt, subst("_letter_" "_")
	renvars *_review_dt, subst("_review_" "_")
	
	des
	
	replace assessment_type = "SKPKB" if assessment_type=="SKPKBT"
	
	tempfile all 
	sa `all'
	
	* Dummy for each asssessment type (STP, SKPKB), year, and letter type
	levelsof assessment_type, local(types) clean
	
	foreach atype in `types'{
		
		u `all', clear
		
		keep if assessment_type=="`atype'"
		
		local minyear = ${minyear}
		local maxyear = ${maxyear}
		forvalues y=`minyear'/`maxyear'{
			foreach x in 	assessment warning enforcement ///
					warrant confiscation ///
					objection judicial appeal{
			
			qui gen double `x'`y' = ( year(`x'_dt) == `y' )  /* if !missing(`x'_dt) */
			
			}
			
		}
		
		keep npwp *20*
		
		des
		
		// Collapse by taxpayer level
		collapse (max) assessment* warning* enforcement* ///
				   warrant* confiscation* ///
				   objection* judicial* appeal* , by(npwp)
		
		reshape long    assessment warning enforcement ///
				warrant confiscation ///
				objection judicial appeal,  ///
						i(npwp) j(year)
						
		renvars assessment warning enforcement ///
			warrant confiscation ///
			objection judicial appeal, postf("_`atype'")
						
		tempfile vars`atype'
		sa `vars`atype''
	}

restore

* Merge assessments with main data
foreach atype in `types'{
	merge 1:1 npwp year using `vars`atype''
	keep if _merge==1 | _merge==3
	drop _merge
}

* Replace assessment with zero if missing (that is, indicator for not receiving any assessment letters
foreach var of varlist  assessment* warning* enforcement* ///
			warrant* confiscation* ///
			objection* judicial* appeal*{
	replace `var' = 0 if missing(`var')

}

* Any assessment, any warnings, any other letters
foreach x in 	assessment warning enforcement ///
		warrant confiscation ///
		objection judicial appeal{
	
	egen double any_`x' = rowmax(`x'*)

}

*******************************************
*********** Merge SPT 1721 data ***********
*******************************************

* IMPORTANTL Rp figures are already in IDR billion
merge 1:1 npwp year using "${output}/analysis/SPT_1721_annual_clean_analysis.dta"
keep if _merge==1 | _merge==3
drop _merge

*************************************************************************
******************** 3. Treatment probability estimation ****************
*************************************************************************

* Match 2008 Jakarta Barat selection using 2005 data
replace selection_yr = 2007 if selection_yr==2008

keep if inrange(year,2003,2005)

* Note: since now restriction is that payments and filings be paid or filed
* 		by June of following tax year, all data in the setup file has
*		2003-2005 payment and filing dates prior to selection date

gen double base =.
replace base = selection_yr - year
drop year

tab base, m

* Keep treatment and baseline data
ds, v(32)

* Variables not to be used in prediction
drop inMTOby2009 inMTOby2010 inMTOby2011 inMTOby2007 mto kpp klu2

ds npwp inMTOby2008 selection_mto selection_yr base origin_kpp klu_1721, not v(32)

reshape wide `r(varlist)', i(npwp inMTOby2008 selection_mto selection_yr origin_kpp klu_1721) j(base)

*************************************************************************
**************** Taxpayers in the same support **************************
*************************************************************************

foreach base in 2 3 4{
	foreach var in gincome ppHN_total{

		forvalues i=0/1{
			qui egen double p975`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(97.5)
			qui egen double p025`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(2.5)
			
			qui sum p975`var'`i'
			local p975`var'`i' = `r(mean)'
			
			qui sum p025`var'`i'
			local p025`var'`i' = `r(mean)'

		}
		
		gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
		gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
		
	}	
	
	
	drop p975* p025*
}

gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
						( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
						!missing(gincome2) & !missing(ppHN_total2)

gen double comsup23 = 	comsup2==1 & ///
							( gincome3 > lbgincome3 & gincome3< ubgincome3 ) & ///
							( ppHN_total3 > lbppHN_total3 & ppHN_total3 < ubppHN_total3 ) & ///
							!missing(gincome3) & !missing(ppHN_total3)
	
gen double comsup24 = comsup23 == 1 & ///
						( gincome4 > lbgincome4 & gincome4 < ubgincome4) & ///
						( ppHN_total4 > lbppHN_total4 & ppHN_total4 < ubppHN_total4) & ///
						!missing(gincome4) & !missing(ppHN_total4)
						
drop lb* ub*

***********************************************************
********************* Rforest weights *********************
***********************************************************

* Keep common support of years 2003-2005
keep if comsup24==1
drop comsup* selection_yr

qui tab selection_mto, gen(fe_mto)
qui tab origin_kpp, gen(fe_okpp)
qui tab klu_1721, gen(fe_klu_1721)

****** Store as long integer to make sure Java will read correctly as numeric ******

/* First convert back to Rp from billion Rp */

ds inMTOby2008 npwp origin_kpp klu selection_mto fe_* any* assess* appeal* warrant* num* ontime*, not

foreach var of varlist `r(varlist)'{
	replace `var' = round(`var'*10^9)
}

ds inMTOby2008 npwp origin_kpp klu selection_mto, not
local features "`r(varlist)'"

foreach var of varlist `features'{
	gen long l_`var' = `var'
	format `var' %8.0g
	drop `var'
	ren l_`var' `var'
}

rforest inMTOby2008 `features', type(class)

mat importance = e(importance)
mat list importance

predict rforest_inMTO_0 rforest_inMTO_1, pr

regress inMTOby2008 rforest_inMTO_1

keep npwp inMTOby2008 rforest_inMTO_0 rforest_inMTO_1

saveold "${output}/analysis/MTO_rforest_weights.dta", replace	

clear
log close
