* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/3_1_MTO_WDD_regressions_main.log", replace
di in red "3_1_MTO_WDD_regressions_main.do"

**********************************
*** 0.1 Define locals/globals ****
**********************************

* Toggles that switch different parts of the code on and off
local addoutcomes	= 1
local analysis		= 1
local total_effect	= 1		/* Computes aggregate effect across all MTO taxpayers */
local graphregs		= 1		/* Plots annual regression coefficients */

global minyear 		= 2003
global maxyear 		= 2011
global baseyear 	= 2005
global treatyear 	= 2006

* All weights and all clusters for robustness
local  allweights "w0 w01 e2 e24 w2 w24"
local  allclust "npwp origin_kpp selection_mto"
local  graphweights "e2"

* Program to store coefficients from annual regressions	
	* Local 1: variable
	* Local 2: first stage or reduced form
	
	global coeffscons = ${maxyear}-${minyear}
	
	cap program drop storeiv
	program define storeiv
		
		mat bmain 	= b[1..${coeffscons},1]
		mat semain	= se[1..${coeffscons},1]
		
		count if esample==1 & inMTOby2008==1
		local Nmto = r(N)
		count if esample==1
		local N = r(N)
		
		unique npwp if esample==1 & inMTOby2008==1
		local umto = r(unique)
		unique npwp if esample==1
		local uall = r(unique)
		
		mat emp = J(${coeffscons}-4,1,.)
		mat N = `Nmto' \ `N' \ `umto' \ `uall' \ emp
		matrix `1' 	  	= (bmain, semain, N)
		
		matrix colnames `1' = b`1' se`1'  N`1'
		
		mat list `1'
		
		preserve
			clear
			svmat `1'
			ren `1'1 	b
			ren `1'2 	se
			ren `1'3 	N
			
			gen inMTOby2008=1
			gen year = ${minyear} + _n -1
			replace year = year+1 if year>=${baseyear}
			
			saveold "${output}/analysis/regcoeffs/MTO_DD_`1'_`2'.dta", replace
		restore
	end
	

	*************************************
	*********** Add outcomes ************
	*************************************
	
if `addoutcomes'==1{
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_weights.dta", clear
	
	* CIT refund
	gen double refund = -paidvalue if paidvalue <0
	replace refund = 0 if missing(refund)
	
	* No taxes paid are zero taxes paid
	misstable sum  ppH* ppN*
	foreach var of varlist ppH* ppN*{
		qui replace `var' = 0 if missing(`var')
	}
	
	*******************************
	*** Merge corrections data ****
	*******************************
	cap drop tax_yr
	cap drop correction corrected
	foreach type in filing tax{
		ren year `type'_yr
		merge 1:1 npwp `type'_yr using "${output}/analysis/SPT_1771_anycorr_`type'_yr.dta"
		keep if _merge==1 | _merge==3
		replace anycorr_`type'_yr = 0 if missing(anycorr_`type'_yr)
		drop _merge
		ren `type'_yr year
	}
	
	***************************
	*** Merge audits data *****
	***************************
	
	preserve
		u "$output/analysis/audits_clean.dta", clear
		keep npwp a4 audit_dt
		gen double year = year(audit_dt)
		
		keep npwp year
		duplicates drop
		
		tempfile audits
		sa `audits'
	restore
	
	merge m:1 npwp year using `audits'
	keep if _merge==1 | _merge==3
	gen audited = (_merge==3)
	drop _merge
	
	*********************************************
	*********** Merge assessment data ***********
	*********************************************
	preserve
		// NPWPs in analysis file
		keep npwp
		duplicates drop
		tempfile npwps
		sa `npwps'

		// Get enforcement data - for now just dummies of each type of letter
		u "${output}/analysis/stpskp_ppn_all_clean.dta", clear
		destring npwp, replace force
		format npwp %15.0g
		
		merge m:1 npwp using `npwps'
		keep if _merge==3
		drop _merge
		
		keep npwp *_dt appeal_dt assessment_type
		
		* Shorten names
		renvars *_letter_dt, subst("_letter_" "_")
		renvars *_review_dt, subst("_review_" "_")
		
		des
		
		replace assessment_type = "SKPKB" if assessment_type=="SKPKBT"
		
		tempfile all 
		sa `all'
		
		* Dummy for each asssessment type (STP, SKPKB), year, and letter type
		levelsof assessment_type, local(types) clean
		
		foreach atype in `types'{
			
			u `all', clear
			
			keep if assessment_type=="`atype'"
			
			local minyear = ${minyear}
			local maxyear = ${maxyear}
			forvalues y=`minyear'/`maxyear'{		
				qui gen double assessment`y' = ( year(assessment_dt) == `y' ) 
			}
			
			keep npwp *20*
			
			des
			
			// Collapse by taxpayer level
			collapse (max) assessment* , by(npwp)
			
			reshape long    assessment,  ///
							i(npwp) j(year)
							
			renvars assessment, postf("_`atype'")
							
			tempfile vars`atype'
			sa `vars`atype''
		}
	
	restore
	
	* Merge assessments with main data
	foreach atype in `types'{
		merge 1:1 npwp year using `vars`atype''
		keep if _merge==1 | _merge==3
		drop _merge
	}
	
	* Replace assessment with zero if missing
	foreach var of varlist  assessment*{
		replace `var' = 0 if missing(`var')
	
	}
	
	egen double any_assessment = rowmax(`x'*)
	
	*******************************************
	*********** Merge SPT 1721 data ***********
	*******************************************
	
	* IMPORTANTL Rp figures are already in IDR billion
	merge 1:1 npwp year using "${output}/analysis/SPT_1721_annual_clean_analysis.dta"
	keep if _merge==1 | _merge==3
	drop _merge
	
	* 2008 data is mostly missing, replace with missing so 2008 is never used
	foreach var of varlist num* inc*{
		replace `var'=. if year==2008
	}

	* Total employment
	gen double num_workers  	= num_perm + num_temp
	gen double wagebill			= inc_perm + inc_temp
	
	* Mean wage
	gen double wage 		= wagebill/num_workers 
	
	**************************************
	* Deflate Rp denominated #s to 2007 Rp
	**************************************
	preserve
		insheet using "${raw}/auxiliary/indonesia_gdp_deflator_FRED.csv", clear
		replace date = substr(date,1,4)
		destring date, replace
		replace date = date-1	// End of year 
		ren idngdp deflator		// end-of-2014 Rp
		ren date year
		
		* Get deflator relative to 2007 Rp
		gen double def07 = deflator if year==2007
		egen def07m = max(def07)
		drop def07
		
		gen double deflator2007 = (deflator/def07m)*100
		drop def07m
		
		// Rescale so that it's 1 in 2007
		replace deflator2007=deflator2007/100
		
		keep year deflator2007
		tempfile deflator
		sa `deflator'
	restore
	
	merge m:1 year using `deflator'
	keep if _merge==3
	drop _merge
	
	foreach var of varlist wage* inc_perm inc_temp ///
				nincome tincome gincome cgsold pphtotal citdue totcitdue paidvalue refund ///
				nincbus nincsidebus domcomninc forcomninc totcomninc ntaxinc  ///
				adjforcred totposadj totnegadj facilityinv comploss otherexpense ///
				ppH* ppN*  {
				
				gen double `var'Rp07 = `var'/deflator2007
				
	}
	
	tab year inMTOby2008
	unique npwp
	unique npwp if inMTOby2008==1
	
	saveold "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", replace
}
****************************************************************************
****************************** Regressions *********************************
****************************************************************************

if `analysis'==1{

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
	
	* Shorten entropy weight names
	renvars eweight*, subst("eweight" "e")
	gen w0 = 1
	gen w01 = 1 if !missing(e2)
	
	* Profit margin 
	gen double nincbus2gincome = nincbus/gincome if totcitdue>0
	sum nincbus2gincome, detail
	replace nincbus2gincome = . if nincbus2gincome>`r(p99)' | nincbus2gincome<`r(p1)'
	
	* Income tax 
		* Adjustment: for CIT paid calculation below, replace totcitdue as zero if missing so payments not missing
		gen double totcitdue_nRp07 = totcitdueRp07
		replace totcitdue_nRp07 = 0 if missing(totcitdue_nRp07)

		qui gen double ppH_2529_2223Rp07    	  	= ppH_2529_corpRp07 + ppH_22Rp07 + ppH_22_impRp07 + ppH_23Rp07
		qui gen double ppH_CITpaidRp07		  	= min(ppH_2529_2223Rp07, max(totcitdue_nRp07,ppH_2529_corpRp07))
		qui gen double ppH_CITpaid_adjRp07		= ppH_CITpaidRp07  - refundRp07
		
		* Other income taxes
		qui gen double ppH_OTHERRp07  	 = ppH_finalRp07 + ppH_oilgasRp07  + ppH_nonoilgasRp07 + ppH_2529_indRp07 + (ppH_2529_2223Rp07 - ppH_CITpaidRp07)
		qui gen double ppH_PAYROLLRp07 	 = ppH_21Rp07 + ppH_26Rp07
		qui gen double ppH_PENALTIESRp07 = ppH_interestRp07
		qui gen double ppH_notCITRp07	 = ppH_PAYROLLRp07 + ppH_OTHERRp07 + ppH_PENALTIESRp07
		
		qui gen double ppH_total_nRp07		= ppH_totalRp07 - ppH_PENALTIESRp07
		qui gen double ppH_total_adjRp07		= ppH_totalRp07 - refundRp07 
		
	* VAT subcategories
		qui gen double ppN_OTHERRp07 		= ppN_otherRp07 + ppN_BMimpRp07 + ppN_BMdomRp07
		qui gen double ppN_PENALTIESRp07 	= ppH_interestRp07
		qui gen double ppN_total_nRp07		= ppN_totalRp07 - ppN_PENALTIESRp07
		
	* Other total subcategories
		qui gen double ppHN_PENALTIESRp07 	= ppH_interestRp07 + ppN_interestRp07
		qui gen double ppHN_total_nRp07 		= ppH_total_nRp07 + ppN_total_nRp07
		qui gen double ppHN_total_adjRp07	= ppHN_totalRp07 - refundRp07 

	* Nominals for Counterfactual
	qui gen double ppH_2529_2223    	= ppH_2529_corp + ppH_22 + ppH_22_imp + ppH_23
	qui gen double ppH_CITpaid		  	= min(ppH_2529_2223, max(totcitdue_n,ppH_2529_corp))
	qui gen double ppH_CITpaid_adj		= ppH_CITpaid  - refund
	qui gen double ppH_total_adj		= ppH_total - refund 
	
	drop totcitdue_n* 
	
	* Collection rate
	gen double CITcolrate = ppH_CITpaid/totcitdue
	
	************* Cost of goods sold by base year reported profits *************
	* Reported profit at base year
	gen temp = tincome if year==${baseyear}
	bys npwp: egen  tincome${baseyear} = max(temp)
	drop temp
	
	gen double cgsoldRp07_g0 = cgsoldRp07 if tincome${baseyear}>0 & !missing(tincome${baseyear})
	gen double cgsoldRp07_l0 = cgsoldRp07 if tincome${baseyear}<=0 & !missing(tincome${baseyear})
	
	* Marginal tax rates pre-reform (schedule based on taxable income)
	gen mrate = .
	replace mrate = .10 if year<2009 & tincome<=.05			
	replace mrate = .15 if year<2009 & tincome>0.05 & tincome<=.1
	replace mrate = .30 if year<2009 & tincome>0.1 & !missing(tincome)
	
	* Marginal tax rates post-reform (schedule based on gross income)
	
	* Taxpayers below 4.8 and above 50
	replace mrate = .5*.28 if year==2009 & gincome<=4.8
	replace mrate = .5*.25 if year>=2010 & gincome<=4.8
	replace mrate = .28 if year==2009 & gincome>50 & !missing(gincome)
	replace mrate = .25 if year>=2010 & gincome>50 & !missing(gincome)
	
	* Taxpayers between 4.8 and 50
	gen tau1 		= .5*.28 if year==2009
	replace tau1	= .5*.25 if year>=2010
	gen tau2 		= .28 if year==2009
	replace tau2	= .25 if year>=2010
	
	replace mrate = tau1*4.8/gincome + tau2*(1- 4.8/gincome) if year>=2009 & gincome>4.8 & gincome<=50
	
	* MTR should not be defined if defining criterion don't exist
	assert missing(mrate) if (missing(tincome) & year<2008) | (missing(gincome) & year>=2009)

	********************************************
	** Save data with means for levels graphs **
	********************************************
	preserve
		collapse (mean) ppHN_total_adjRp07 totcitdueRp07 tincomeRp07  gincomeRp07 ///	
				 (count) npwp [pw=e2], by(year inMTOby2008)
		gen weight = "e2"
		
		saveold "${output}/analysis/regcoeffs/MTO_analysisfile_annual_means_${minyear}_${maxyear}.dta", replace
	restore
	
	******************************************
	********** Regression variables **********
	******************************************

	local minyear = ${minyear}
	local maxyear = ${maxyear}
	
	* Instruments year by year
	forvalues i=`minyear'/`maxyear'{
		gen double inMTOby2008_`i' = inMTOby2008*(year==`i')
		gen double y`i' = (year == `i')
	}

	* Endogenous (use variable mto : in MTO in year x)
	gen double inMTO = mto
	
	* 2007 delayed flagging of MTO - know per 2007 regulations they are in MTO
	replace inMTO = 1 if year==2007 & inMTOby2008==1 & selection_yr==2007
	
	* Year by year endogenous variable
	forvalues y=`minyear'/`maxyear'{
		gen double end_inMTO`y' = (year==`y' & inMTO==1) if !missing(inMTO)
	}
	
	* Ommit base year instruments and endogenous variable
	renvars inMTOby2008_${baseyear} end_inMTO${baseyear}  y${baseyear}, pref("ommit_")
	
	gen double post = (year>=${treatyear})
	gen double inMTOby2008post = inMTOby2008*post
	
	*********************************************************************************
	**************** IV regression with 1 endogenous variable, 1 instrument *********
	*********************************************************************************
	
	* Weights for each clustering level
	local npwp_w 			"`allweights'"
	local origin_kpp_w 		"e2"
	local selection_mto_w 	"e2"
	
	* Line-by-line regressions 
		
		local main1  			"tincomeRp07 gincomeRp07 totcitdueRp07"
		local main2				"ppH_CITpaid_adjRp07 ppH_notCITRp07 ppN_totalRp07 ppHN_total_adjRp07"
		local dettotcitdueRp07  "tincomeRp07 totcitdueRp07 pphtotalRp07"
		local dettincomeRp07    "nincomeRp07 complossRp07"
		local detnincomeRp07    "totcomnincRp07 ntaxincRp07 totposadjRp07 totnegadjRp07 facilityinvRp07"
		local detcnincomeRp07   "domcomnincRp07 forcomnincRp07"
		local detdcnincomeRp07  "nincbusRp07 nincsidebusRp07"
		local detnincbusRp07	"gincomeRp07 cgsoldRp07 otherexpenseRp07 nincbus2gincome"
		local dettaxpaid1Rp07	"CITcolrate  ppHN_totalRp07  ppHN_total_nRp07 ppHN_total_adjRp07 ppHN_PENALTIESRp07"
		local dettaxpaid2Rp07	"ppN_totalRp07  ppN_total_nRp07 ppN_PENALTIESRp07 ppN_impRp07 ppN_domRp07 ppN_OTHERRp07"
		local dettaxpaid3Rp07	"ppH_totalRp07  ppH_total_nRp07 ppH_total_adjRp07 ppH_PENALTIESRp07"
		local dettaxpaid4Rp07	"ppH_CITpaidRp07 ppH_CITpaid_adjRp07 ppH_notCITRp07 ppH_OTHERRp07 ppH_PAYROLLRp07 ppH_2529_2223Rp07 "
		local detassess1Rp07	"any_assessment "
		local detassess2Rp07	"assessment_STP "
		local detassess3Rp07	"assessment_SKPKB"
		local detcorrectRp07	"anycorr_filing_yr anycorr_tax_yr"
		local detemployRp07		"num_workers num_perm num_temp wagebillRp07 inc_permRp07 inc_tempRp07 wageRp07"

		* Sets of sets
		local mainset "main1 main2 detemployRp07"
		
		local detset1 "dettotcitdueRp07 dettincomeRp07 detnincomeRp07 detcnincomeRp07 detdcnincomeRp07 detnincbusRp07"
		local detset2 "dettaxpaid1Rp07 dettaxpaid2Rp07  dettaxpaid3Rp07 dettaxpaid4Rp07 detassess1Rp07 detassess2Rp07"
		local detset3 "detassess3Rp07 detemployRp07 detcorrectRp07"
		
	local ivregs_1endog = 1
	
	if `ivregs_1endog'==1{
	
		* First, get estimates for counterfactual, based on current (not real) Rp
		foreach var of varlist ppH_CITpaid_adj ppH_total_adj{
			ivreghdfe `var'  (inMTO =  inMTOby2008post) [pw=e2], absorb(npwp  year) cluster(npwp)
			local iv_b 	= _b[inMTO]
			local iv_se	= _se[inMTO]
			count if e(sample)
			local obs = r(N)
			mat `var'out = (`iv_b',`iv_se', `obs')
			
			preserve
				clear
				svmat `var'out
				ren `var'out1 b
				ren `var'out2 se
				ren `var'out3 N
				gen weight="e2"
				gen cluster = "npwp"
				gen var = "`var'"
				
				tempfile o`var'
				sa `o`var''
			restore
		}
		
		preserve
			u `oppH_CITpaid_adj', clear
			append using `oppH_total_adj'
			
			saveold "${output}/analysis/regcoeffs/MTO_DD_for_counterfactual.dta", replace
		restore
		
		* Now, regression of remaining variables in real terms 
		foreach clust in `allclust' {
			foreach weight in ``clust'_w'{
			
				if "`clust'"=="npwp" & "`weight'"=="e2"{
					local sets "`detset1' `detset2' `detset3'"
				}
				else{
					local sets "`mainset'"
				}
			
			foreach set in  `sets' {
				
				foreach var of varlist ``set''{
					
						estimates clear
						if "`set'"=="detemployRp07" {
							ivreghdfe `var'  (inMTO =  	inMTOby2008post ) ///		
										  [pw=`weight'] if year!=2008, absorb(npwp  year )  savefirst saverf cluster(`clust')
						}
						else{
							ivreghdfe `var'  (inMTO =  inMTOby2008post) [pw=`weight'], absorb(npwp  year) savefirst saverf cluster(`clust')
						}
						
						******** Coeffs *********
						local iv_b 	= _b[inMTO]
						local iv_se	= _se[inMTO]
						local FS_F 	= e(first)[4,1]
						gen esample = e(sample)
						
						estimates restore _ivreg2_inMTO
						local fs_b 	= _b[inMTOby2008post]
						local fs_se	= _se[inMTOby2008post]
												
						estimates restore _ivreg2_`var'
						local rf_b 	= _b[inMTOby2008post]
						local rf_se	= _se[inMTOby2008post]
						
						********** Counts ***********
						unique npwp if esample
						local allids = r(unique)
						unique npwp if esample & inMTOby2008==1
						local mtoids = r(unique)
						
						count if esample
						local allobs= r(N)
						count if esample & inMTOby2008==1
						local mtoobs= r(N)
						
						* Pre period average
						sum `var' if  year==${baseyear} [w=`weight']
						local m`var' = r(mean)
						sum `var' if inMTOby2008==0 & year==${baseyear} [w=`weight']
						local m`var'0 = r(mean)
						sum `var' if inMTOby2008==1 & year==${baseyear} [w=`weight']
						local m`var'1 = r(mean)
						
						* Post period average by Instrument (inMTOby2008) & Treatment status (inMTO in current year)
						sum `var' if esample & year>=${treatyear} [w=`weight']
						local p`var' = r(mean)
						sum `var' if inMTOby2008==0 & inMTO==0 & esample & year>=${treatyear} [w=`weight']
						local p`var'0 = r(mean)
						sum `var' if inMTOby2008==1 & inMTO==1 & esample & year>=${treatyear} [w=`weight']
						local p`var'1 = r(mean)
						
						drop esample
						mat `var'`weight' = 	(`iv_b', `iv_se', ///
												 `rf_b', `rf_se', ///
												 `fs_b', `fs_se', `FS_F', ///
												 `allids',`mtoids', ///
												 `m`var'', `m`var'0',`m`var'1', `p`var'', `p`var'0',`p`var'1', `allobs',`mtoobs')
						
						* Save coefficients
						preserve
							clear
							svmat `var'`weight'
							gen var = "`var'"
							gen set = "`set'"
							gen weight = "`weight'"
							
							ren `var'`weight'1 iv_b
							ren `var'`weight'2 iv_se
							ren `var'`weight'3 rf_b
							ren `var'`weight'4 rf_se
							ren `var'`weight'5 fs_b
							ren `var'`weight'6 fs_se
							ren `var'`weight'7 fs_F
							ren `var'`weight'8 IDs_all
							ren `var'`weight'9 IDs_mto
							ren `var'`weight'10 mean_pre
							ren `var'`weight'11 mean_pre_Z0D0
							ren `var'`weight'12 mean_pre_Z1D1
							ren `var'`weight'13 mean_post
							ren `var'`weight'14 mean_post_Z0D0
							ren `var'`weight'15 mean_post_Z1D1
							ren `var'`weight'16 obs_all
							ren `var'`weight'17 obs_mto
							
							tempfile `var'`weight'
							sa ``var'`weight''
						restore
								
						estimates clear
					
					} /* vars boolean */	
					} /* Set boolean */
				} /* Weights */
			
			**************** Append a single file for the clustering option ****************
			preserve
			
				u `tincomeRp07e2', clear
				
				foreach weight in ``clust'_w'{
					foreach x in `' `dettotcitdueRp07' `dettincomeRp07' `detnincomeRp07' `detcnincomeRp07' `detdcnincomeRp07' `detnincbusRp07' ///
					`dettaxpaid1Rp07' `dettaxpaid2Rp07'  `dettaxpaid3Rp07' `dettaxpaid4Rp07' ///
					`detassess1Rp07' `detassess2Rp07' `detassess3Rp07' `detemployRp07' `detcorrectRp07' {
						
						cap append using ``x'`weight''
					} /* x */
				} /* weights */
				
				order set var, first
				
				duplicates drop
				outsheet using "${output}/analysis/csv/MTO_DD_SE`clust'.csv", comma replace
			restore
		
		} /* Close clust */
		
	} /* close ivregs_1endog */
	
	***************************************************************
	******* Year by year reduced form and first stage plots *******
	***************************************************************

	local by_year_plots = 1
	if `by_year_plots'==1{
	
		***** Taxpayers in and out of MTO from dataset with no weights *****
		preserve
			u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", clear
			
			mat counts = J(5,1,.)
			unique npwp if inMTOby2008 ==1
			mat counts[1,1]=`r(unique)'
			unique npwp if inMTOby2008 ==1 & (year==2008 & mto==0)
			mat counts[2,1]=`r(unique)'
			unique npwp if inMTOby2008 ==1 & (year==2009 & mto==0)
			mat counts[3,1]=`r(unique)'
			unique npwp if inMTOby2008 ==1 & (year==2010 & mto==0)
			mat counts[4,1]=`r(unique)'
			unique npwp if inMTOby2008 ==1 & (year==2011 & mto==0)
			mat counts[5,1]=`r(unique)'
			
			clear
			svmat counts
			gen status = ""
			replace status = "Assigned in 2007" if _n==1
			replace status = "Moved to PTO by 2008" if _n==2
			replace status = "Moved to PTO by 2009" if _n==3
			replace status = "Moved to PTO by 2010" if _n==4
			replace status = "Moved to PTO by 2011" if _n==5
			
			order counts
			outsheet using "${output}/analysis/csv/moved_out_of_mto.csv", comma replace
		restore
	
		************ One first stage graph ************
		
		areg inMTO  	inMTOby2008_2003 	inMTOby2008_2004 ///
						inMTOby2008_2006 	inMTOby2008_2007 ///
						inMTOby2008_2008  	inMTOby2008_2009 ///
						inMTOby2008_2010    inMTOby2008_2011  y20*  ///
					[pw=e2], absorb(npwp) vce(cluster npwp)
		
		gen double esample = e(sample)
		
		* First stage
		cap mat drop b
		cap mat drop se
		mat b 	= e(b)'
		mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
		storeiv inMTO first
		
		drop esample
		
		************ Reduced form ************	
		foreach var of varlist ///
				mrate cgsoldRp07_g0 cgsoldRp07_l0 ///
				ppHN_total_adjRp07 gincomeRp07 ///
				tincomeRp07 totcitdueRp07  ///
				nincomeRp07 otherexpenseRp07 cgsoldRp07 ///
				wagebillRp07 inc_tempRp07 inc_permRp07  ///
				num_workers num_perm num_temp{
				
				if "`var'"=="num_workers" | "`var'"=="num_perm" | "`var'"=="num_temp" | ///
						 "`var'"=="wagebillRp07" | "`var'"=="inc_permRp07" | "`var'"=="inc_tempRp07"{
					areg `var'  inMTOby2008_2003 	inMTOby2008_2004 ///
								inMTOby2008_2006 	inMTOby2008_2007 ///
								inMTOby2008_2008  	inMTOby2008_2009 ///
								inMTOby2008_2010    inMTOby2008_2011  y20*  ///
							[pw=e2] if year!=2008, absorb(npwp) vce(cluster npwp)
		
				}
				else{
					areg `var'  inMTOby2008_2003 	inMTOby2008_2004 ///
								inMTOby2008_2006 	inMTOby2008_2007 ///
								inMTOby2008_2008  	inMTOby2008_2009 ///
								inMTOby2008_2010    inMTOby2008_2011 y20*  ///
								[pw=e2], absorb(npwp)  vce(cluster npwp)
				}
				
					gen double esample = e(sample)
					
					* Reduced form
					cap mat drop b
					cap mat drop se
					mat b 	= e(b)'		
					mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
					storeiv `var' reduced
					
					estimates clear
					drop esample
				
				**** Test Difference in IV coeff for gross income and total taxes paid
				**** 2007 vs 2011, and 2008 vs 2011 3 years vs 6 years out ****
					if "`var'"=="gincomeRp07" | "`var'"=="ppHN_total_adjRp07"{
						* Matrix for storing RF and IV difference in coefficients at 2008 and at 2011
						mat yd`var' = J(1,21,.)
						
						* Reduced form
						areg `var'  inMTOby2008_2003 	inMTOby2008_2004 ///
								inMTOby2008_2006 	inMTOby2008_2007 ///
								inMTOby2008_2008  	inMTOby2008_2009 ///
								inMTOby2008_2010    inMTOby2008_2011 y20*  ///
								[pw=e2], absorb(npwp)  vce(cluster npwp)
								
						test inMTOby2008_2007 = inMTOby2008_2011
						mat yd`var'[1,1] = `r(p)'
						
						test inMTOby2008_2008 = inMTOby2008_2011
						mat yd`var'[1,2] = `r(p)'
						
						* IV
						qui ivreghdfe `var'  y20* (end_inMTO* =  inMTOby2008_2003 	inMTOby2008_2004 ///
												inMTOby2008_2006 	inMTOby2008_2007 ///
												inMTOby2008_2008  	inMTOby2008_2009 ///
												inMTOby2008_2010    inMTOby2008_2011) ///
												[pw=e2], absorb(npwp) cluster(npwp)
						
						gen double esample = e(sample)
						
						// 2007-2011
						test end_inMTO2007 = end_inMTO2011	
						mat yd`var'[1,3] = `r(p)'
						
						// 2008-2011
						test end_inMTO2008 = end_inMTO2011	
						mat yd`var'[1,4] = `r(p)'
						
						// Coefficients
						mat yd`var'[1,5] = _b[end_inMTO2007]
						mat yd`var'[1,6] = _se[end_inMTO2007]
						
						mat yd`var'[1,7] = _b[end_inMTO2008]
						mat yd`var'[1,8] = _se[end_inMTO2008]
						
						mat yd`var'[1,9] = _b[end_inMTO2011]
						mat yd`var'[1,10] = _se[end_inMTO2011]
						
						// Treated post means
						sum `var' if inMTOby2008==1 & end_inMTO2007==1 & year==2007 & esample==1
						mat yd`var'[1,11] = `r(mean)'
						local treat2007 = `r(mean)'
						
						sum `var' if inMTOby2008==1 & end_inMTO2008==1 & year==2008 & esample==1
						mat yd`var'[1,12] = `r(mean)'
						local treat2008 = `r(mean)'
						
						sum `var' if inMTOby2008==1 & end_inMTO2011==1 & year==2011 & esample==1
						mat yd`var'[1,13] = `r(mean)'
						local treat2011 = `r(mean)'
						
						// Counterfactual mean 2007
						lincom `treat2007' - _b[end_inMTO2007]
						mat yd`var'[1,14] = `r(estimate)'
						mat yd`var'[1,15] = `r(se)'

						// Counterfactual mean 2008
						lincom `treat2008' - _b[end_inMTO2008]
						mat yd`var'[1,16] = `r(estimate)'
						mat yd`var'[1,17] = `r(se)'

						// Counterfactual mean 2011
						lincom `treat2011' - _b[end_inMTO2011]
						mat yd`var'[1,18] = `r(estimate)'
						mat yd`var'[1,19] = `r(se)'
						
						// Test difference in 2007-2011 counterfactual means
						testnl _b[end_inMTO2007]/(`treat2007' -_b[end_inMTO2007]) = _b[end_inMTO2011]/(`treat2011' -_b[end_inMTO2011])
						mat yd`var'[1,20] = `r(p)'
						
						// Test difference in 2008-2011 counterfactual means
						testnl _b[end_inMTO2008]/(`treat2008' -_b[end_inMTO2008]) = _b[end_inMTO2011]/(`treat2011' -_b[end_inMTO2011])
						mat yd`var'[1,21] = `r(p)'
						
						drop esample
						**** Append RF and IV coeff differences *****
						preserve
							clear

							svmat yd`var'
							gen var = "`var'"
							ren yd`var'1 rf_0711diff_pval
							ren yd`var'2 rf_0811diff_pval
							ren yd`var'3 ss_0711diff_pval
							ren yd`var'4 ss_0811diff_pval
							ren yd`var'5 b_end_inMTO2007
							ren yd`var'6 se_end_inMTO2007
							ren yd`var'7 b_end_inMTO2008
							ren yd`var'8 se_end_inMTO2008
							ren yd`var'9 b_end_inMTO2011
							ren yd`var'10 se_end_inMTO2011
							ren yd`var'11 inMTOby2008_2007_mean
							ren yd`var'12 inMTOby2008_2008_mean
							ren yd`var'13 inMTOby2008_2011_mean
							ren yd`var'14 counterfactual07_estimate
							ren yd`var'15 counterfactual07_se
							ren yd`var'16 counterfactual08_estimate
							ren yd`var'17 counterfactual08_se
							ren yd`var'18 counterfactual11_estimate
							ren yd`var'19 counterfactual11_se	
							ren yd`var'20 iv_pctcount_0711diff_pval
							ren yd`var'21 iv_pctcount_0811diff_pval
							
							order var
							tempfile y`var'
							sa `y`var''
						restore
						
						} /* If var is gross income or total taxes paid */
			} /* var*/
			
			* Append
			u `ygincomeRp07', clear
			append using `yppHN_total_adjRp07'
			outsheet using "${output}/analysis/csv/MTO_DD_year2year_diff.csv", comma replace
				
	} /* Close second stage plots boolean */
	
} /* Close analysis */

	*******************************************
	************* Total MTO effect ************
	*******************************************
	
if `total_effect'==1{
	
	* Get effect on total taxes
	insheet using "${output}/analysis/csv/MTO_DD_SEnpwp.csv", clear
	ds, v(32)
	keep if weight=="e2" & var=="ppHN_total_adjRp07"
	
	cap ren mean_post_z1d1 mean_post_Z1D1
	keep var iv_b iv_se ids_mto mean_post_Z1D1
	
	* Level effect for analysis sample
	local level_effect_analysis = iv_b*ids_mto*(${maxyear} - ${baseyear})
	
	* % of counterfactual
	gen double iv_pct = iv_b/(mean_post_Z1D1 - iv_b)
	
	tempfile tot
	sa `tot'
	
	********** Compute total effect based on level for entire sample *********
	
	* First, get MTO code for each region
		u "${raw}/auxiliary/kpps_mtos_regions_codes.dta", clear
		keep kpp mto region_mto
		
		keep if mto==1
		destring kpp, replace
		ren kpp mto_code
		keep mto_code region_mto
		duplicates drop
		
		* Pekanbaru and Batam are 2 MTOS under the same region.
		* Create different code so that merging can be proper.
		replace mto_code=999 if inlist(mto_code,217,218)
		
		duplicates drop

		tempfile mtokpp
		sa `mtokpp'
		
		u "${raw}/auxiliary/kpps_mtos_regions_codes.dta", clear
		merge m:1 region_mto using `mtokpp'
		keep if _merge==3
		
		keep kpp region_mto mto_code
		
		tempfile mto_code
		sa `mto_code'
	
	* Get MPN data
		u "${output}/analysis/MPN_detailed_clean.dta", clear
	
		* Keep payment made within 6 months after end of tax year
		keep if payment_dt <= mdy(6,30,tax_yr+1)
		
		* Keep only ppH and ppN type tax
		keep if regexm(tax_type,"^ppH") | regexm(tax_type,"^ppN")
		
		collapse (sum) taxpaid, by(npwp tax_yr tax_type)
		reshape wide taxpaid, i(npwp tax_yr) j(tax_type) string
		renvars taxpaid*, predrop(7)

		ds npwp tax_yr, not
		foreach var of varlist `r(varlist)'{
			replace `var' = 0 if `var'==.
		}
		
		destring npwp, replace force
		format npwp %15.0g
		
		keep if !missing(npwp)
		
		keep npwp tax_yr ppH* ppN*
		
		* Make aggregate variables
		egen double ppH_total = rowtotal(ppH*)
		egen double ppN_total = rowtotal(ppN*)
		gen double  ppHN_total = ppH_total + ppN_total
		
		* Express variables in billions
		foreach var of varlist ppH* ppN*{
			replace `var' = `var'/10^9
		}
		
		keep npwp tax_yr ppHN_total
		
		* Merge taxes paid for year X with treatment status for being in MTO in year X
		ren tax_yr filing_yr
		
		* Note: this definition of MTO does not inclued LTOs and special offices as MTOs
		merge 1:1 npwp filing_yr using "${output}/analysis/mto_treatment_calendar_yr_SPT1771.dta", keepusing(kpp mto_post mto)
		keep if _merge==3
		drop _merge
		
		// Registered with DGT as of 2006
		gen double y2006 = (filing_yr<=2006)
		bys npwp: egen regasof2006 = max(y2006)
		
		// From here on just keep payments data from post period
		keep if inrange(filing_yr,${baseyear}+1,${maxyear})
		
		* Get the regions
		merge m:1 kpp using `mto_code', keepusing(mto_code) keep(3) nogen
		
		bys npwp: egen inMTOby2011 	= max(cond(filing_yr<=2011,mto_post,.))
		
	// Effects for different samples

		* Level effect all Count total taxpayers inMTOby2011 (all ever treated)
		unique npwp if inMTOby2011==1 
	
		local tot_inMTOby2011 = `r(unique)'
		
		* Level effect all Count total taxpayers inMTOby2011 (all ever treated)
		unique npwp if inMTOby2011==1 & regasof2006==1
		
		local tot_inMTOby2011_reg06 = `r(unique)'

		u `tot', clear
		gen double tot_inMTOby2011 	= `tot_inMTOby2011_reg06'
		gen double tot_years		= ${maxyear} - ${baseyear}
		gen double level_effect_all = tot_inMTOby2011*iv_b*tot_years
		
		gen taxpayer_sample = "19 regions registered as of 2006 and in MTO by 2011"
		
		order var iv*
		order *_effect_all, last
		
		outsheet using "${output}/analysis/csv/MTO_total_effect.csv", comma replace

}

	*****************************************
	************* 3. Plot graphs ************
	*****************************************
	
if `graphregs'==1{

* Names for variables plotted graphs
	* Endogenous
	local inMTO "In MTO"
	
	* CIT
	local mrate "Marginal Corporate Income Tax Rate"

	* Employment values (SPT 1721)
	local num_workers "Total employees"
	local num_perm "Total permanent and/or pensioner employees"
	local num_temp "Total temporary employees"
	local wagebillRp07 "Wage bill (2007 IDR billion)"
	local inc_permRp07 "Permanent workers wage bill (2007 IDR billion)"
	local inc_tempRp07 "Temporary workers wage bill (2007 IDR billion)"

	* Reported values
	local gincomeRp07 "Gross income (2007 IDR billion)"
	local tincomeRp07 "Taxable income (2007 IDR billion)"
	local nincomeRp07 "Net income (2007 IDR billion)"
	local cgsoldRp07 "Cost of sales (2007 IDR billion)"
	local totcitdueRp07 "Total CIT due (2007 IDR billion)"
	local otherexpenseRp07 "Other expenses (2007 IDR billion)"
	local cgsoldRp07_g0 "Cost of sales (2007 IDR billion)"
	local cgsoldRp07_l0 "Cost of sales (2007 IDR billion)"
	
	* Payments - Aggregated across branches	
	local ppHN_total_adjRp07 		"VAT + Income tax payments (2007 IDR billion)"
	
	local xtitle "Tax Year"
	
	* Levels graphs
	u "${output}/analysis/regcoeffs/MTO_analysisfile_annual_means_${minyear}_${maxyear}.dta", clear
	
	foreach x in ppHN_total_adjRp07 totcitdueRp07 tincomeRp07  gincomeRp07{

		twoway 	(connect `x' year if inMTOby2008==1 & weight=="e2") ///
				(connect `x' year if inMTOby2008==0 & weight=="e2") , ///
		scheme(s1mono)  ///
		legend(label(1 "In first MTO cohort") label(2 "Not in first MTO cohort")) ///
		ytitle("``x''", size(medium)) yscale(titlegap(*5)) ///
		xlabel(${minyear}(1)${maxyear}) xtitle("`xtitle'")
		graph export "${output}/analysis/graphs/MTO_`x'_e2_averages.pdf", replace
	}

	***************************
	* First stage graph
	u "${output}/analysis/regcoeffs/MTO_DD_inMTO_first.dta", clear
	label variable year "Calendar Year"
	gen n = _n
	
	sort year
	expand 2 in 1
	
	replace year=${baseyear} if _n==1
	
	foreach var of varlist b se{
		replace `var'=0 if year==${baseyear}
	}
	
	gen double lb = b-1.96*se
	gen double ub = b+1.96*se
	
	sum year
	local minyear = `r(min)'
	local maxyear = `r(max)'
	
	sort year
	twoway  (rarea lb ub year, sort color(gs8%30)) ///
			(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
	scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
	ytitle("In MTO", size(medium)) yscale(titlegap(*5)) ///
	xlabel(`minyear'(1)`maxyear') legend(off) 
	graph export "${output}/analysis/graphs/MTO_DD_first.pdf", replace
	***************************
	
	* Reduced form graphs
	foreach x in 	mrate cgsoldRp07_g0 cgsoldRp07_l0 ///
					ppHN_total_adjRp07 gincomeRp07 ///
					tincomeRp07 totcitdueRp07  ///
					nincomeRp07 otherexpenseRp07 cgsoldRp07 ///
					wagebillRp07 inc_tempRp07 inc_permRp07  ///
					num_workers num_perm num_temp{ 
		
		u "${output}/analysis/regcoeffs/MTO_DD_`x'_reduced.dta", clear
		
		gen n = _n
		
		sort year
		expand 2 in 1
		
		replace year=${baseyear} if _n==1
		
		foreach var of varlist b se{
			replace `var'=0 if year==${baseyear}
		}
		
		gen double lb = b-1.96*se
		gen double ub = b+1.96*se
		
		sum year
		local minyear = `r(min)'
		local maxyear = `r(max)'
		
		if 	"`x'"=="num_workers" | "`x'"=="num_perm" | "`x'"=="num_temp" | ///
				 "`x'"=="wagebillRp07" | "`x'"=="inc_permRp07" | "`x'"=="inc_tempRp07"{
				drop if year==2008
		}
		
		sort year
		/* Make gross income and cost of goods sold have the same scale */
		if "`x'"=="gincomeRp07" | "`x'"=="cgsoldRp07"{
			twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
					(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
			scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
			ytitle("``x''", size(medium)) ylabel(0(5)20) yscale(titlegap(*5))  ///
			xtitle("`xtitle'") xlabel(`minyear'(1)`maxyear') legend(off) 
			graph export "${output}/analysis/graphs/MTO_DD_`x'_reduced.pdf", replace
		}
		/* Give same scale as tax rate ranges */
		else if "`x'"=="mrate"{
			twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
					(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
			scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
			ytitle("``x''", size(medium)) yscale(titlegap(*5)) ///
			xtitle("`xtitle'") xlabel(`minyear'(1)`maxyear') ///
			xline(2008, lcolor(red)) yscale(range(-0.1 0.1)) ylabel(-0.1(0.05)0.1) ///
			text(0.015 2008.5 "CIT reform", place(ne)) ///
			legend(off) 
			graph export "${output}/analysis/graphs/MTO_DD_`x'_reduced.pdf", replace
		}
		/* Use same scale for cost of goods sold for diff profit */
		else if "`x'"=="cgsoldRp07_g0" | "`x'"=="cgsoldRp07_l0"{
			twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
					(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
			scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
			ytitle("``x''", size(medium)) yscale(titlegap(*5)) ylabel(0(10)40) ///
			xtitle("`xtitle'") xlabel(`minyear'(1)`maxyear') legend(off) 
			graph export "${output}/analysis/graphs/MTO_DD_`x'_reduced.pdf", replace
		}
		else{
			twoway  (rarea lb ub year, sort lwidth(none) color(gs8%30)) ///
					(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
			scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
			ytitle("``x''", size(medium)) yscale(titlegap(*5)) ///
			xtitle("`xtitle'") xlabel(`minyear'(1)`maxyear') legend(off) 
			graph export "${output}/analysis/graphs/MTO_DD_`x'_reduced.pdf", replace
		}
	
  } /* Close var loop */
	
} /* Close graph boolean */
clear
log close
