* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/5_1_ETI_estimation_main.log", replace
di in red "Run 5_1_ETI_estimation_main.do"

* Figure labels
local gincome "Gross income (IDR billion)"
local tincome "Taxable income (IDR billion)"
local cgsold "Cost of goods sold (IDR billion)"

****** Toggles ******

global minyear  = 2003
global maxyear  = 2011

local schedules  				= 1 /* Simulated data to plot schedules */
local schedule_variation		= 1 /* Simulated data for contours showing schedule change variation as function of simulated taxable and gross income */
local effective_schedules		= 1 /* Schedules with real data  + taxpayer density using all taxpayers in SPT 1771 */

local setup						= 1 /* Create ETI analysis file */
local analysis					= 1 /* Estimate ETI, robustness, and other MTR regressions */

if `schedules'==1{

	*************************************
	********* Pre-reform schedule *******
	*************************************
	
	clear
	set obs 10000
	gen tincome = 100*exp(rnormal())
	
	* Marginal tax rates applied to different amounts
	gen schedule = .
	replace schedule = .10 if tincome<=50
	replace schedule = .15 if tincome>50 & tincome<=100
	replace schedule = .30 if tincome>100
	
	keep if tincome < 150
	sort schedule
	twoway scatter schedule tincome, scheme(s1mono) ///
	ytitle("Marginal Corporate Income Tax Rate") xtitle("Firm taxable income (IDR million)") ylabel(0(0.05).35) 
	graph export "${output}/analysis/graphs/mrates_pre_reform_schedule.eps", replace
	
	**************************************
	********* Post-reform schedule *******
	**************************************
	
	* Generate gross income and taxable income with the correlation structure seen in the data
	* for taxpayers with gincome<100 billion (which is ~ .37).
	
	clear
	matrix C = (1, .37 \ .37, 1)
	corr2data gincome tincome, n(10000) corr(C)
	replace gincome = normal(gincome)*100
	replace tincome = normal(tincome)
	
	* Post-2009 regime marginal rates
	gen MTRpost1 = .
	replace MTRpost1 = .28 if gincome>50		/* Using flat tax as 0.25 (since 2010) */
	replace MTRpost1 = .5*.28 if gincome<=4.8
	replace MTRpost1 = (.5*.28*(4.8/gincome) + .28*(1- 4.8/gincome)) if gincome>4.8 & gincome<=50
	
	gen MTRpost2 = .
	replace MTRpost2 = .25 if gincome>50		/* Using flat tax as 0.25 (since 2010) */
	replace MTRpost2 = .5*.25 if gincome<=4.8
	replace MTRpost2 = (.5*.25*(4.8/gincome) + .25*(1- 4.8/gincome)) if gincome>4.8 & gincome<=50
	
	sort gincome
	twoway  (scatter MTRpost1 gincome, msymbol(O) ) ///
			(scatter MTRpost2 gincome, msymbol(O) ), /// 
	scheme(s1mono) xline(4.8) xline(50) ///
	text(.27 4.8 "IDR 4.8 billion", place(e)) text(.22 50 "IDR 50 billion", place(e)) ///
	legend(label(1 "2009 schedule") label(2 "2010 schedule") ) ///
	ytitle("Marginal Corporate Income Tax Rate") xtitle("Firm gross income (IDR billion)") ylabel(.1(0.05).3) 
	graph export "${output}/analysis/graphs/mrates_post_reform_schedule.eps", replace
}

	*********************************************
	********* Schedule change variation *********
	*********************************************

if `schedule_variation'==1{

	clear
	clear
	set obs 2000000
	gen tincome = runiform(0,1002)	// Between 0 and 1 billion
	gen gincome = runiform(0,102)	// Between 0 and 100 billion
	
	// 2009 schedule
	gen MTRpost1 = .
	replace MTRpost1 = .28 if gincome>50		/* Using flat tax as 0.25 (since 2010) */
	replace MTRpost1 = .5*.28 if gincome<=4.8
	replace MTRpost1 = (.5*.28*(4.8/gincome) + .28*(1- 4.8/gincome)) if gincome>4.8 & gincome<=50
	
	// 2010 schedule
	gen MTRpost2 = .
	replace MTRpost2 = .25 if gincome>50		/* Using flat tax as 0.25 (since 2010) */
	replace MTRpost2 = .5*.25 if gincome<=4.8
	replace MTRpost2 = (.5*.25*(4.8/gincome) + .25*(1- 4.8/gincome)) if gincome>4.8 & gincome<=50
	
	// Pre-2009 schedule
	gen MTRpre = .
	replace MTRpre = .10 if tincome<=50
	replace MTRpre = .15 if tincome>50 & tincome<=100
	replace MTRpre = .30 if tincome>100
	
	// 2009-2008
	gen double MTRchange1 = MTRpost1 - MTRpre
	
	// 2010-2009
	gen double MTRchange2 = MTRpost2 - MTRpost1
	
	egen bintincome = cut(tincome), at(0(1)1001)
	egen bingincome = cut(gincome), at(0(1)101)
	
	collapse (mean) MTRchange1 MTRchange2, by(bintincome bingincome)
	
	* Export csv file to plot eti variation contours
	keep if !missing(bintincome) & !missing(bingincome)
	sort bintincome bingincome
	outsheet using "${output}/analysis/regcoeffs/simulated_data_for_eti_heatmap.csv", comma replace
	
	* Where real data are localted
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
	keep if inrange(year,2008,2009) & tincome>0
	keep if !missing(eweight2)
	xtset npwp year
	
	keep npwp year tincome gincome eweight2 inMTOby2008
	gen double tinc_chng = tincome - tincome[_n-1]
	gen double ginc_chng = gincome - gincome[_n-1]
	
	keep if !missing(tinc_chng) & !missing(ginc_chng)

	keep npwp tincome gincome eweight2 inMTOby2008
	
	* Tincome in millions
	replace tincome = tincome*10^3

	keep npwp tincome gincome eweight2 inMTOby2008
	renvars tincome gincome, postf(2008)
	
	outsheet using "${output}/analysis/regcoeffs/real_data_for_eti_scatter.csv", comma replace
}

	**************************************************************************************
	****** Effective rate schedules and taxpayer density using all SPT 1771 **************
	**************************************************************************************

if `effective_schedules'==1{
	
	u "${output}/analysis/SPT_1771_clean.dta", clear
	
	ren a2jpru 			k_gincome
	ren a2pkp 			k_tincome
	ren a2ppht			k_totcitdue
	
	keep npwp k_* tax_yr kpp filing_dt system_dt correction
	
	renvars k_*, predrop(2)
	
	* In billions
	replace gincome 	= gincome/10^9
	replace tincome 	= tincome/10^9
	replace totcitdue 	= totcitdue/10^9
	
	destring npwp, replace
	format npwp %15.0g
	
	* Replace negative gross income with missing
	replace gincome = .n if gincome<0
	
	* Replace correction is original if missing (no cases)
	replace correction = 0 if missing(correction)
	
	* 20190304 Keep filings filed by 6 months after tax year ends
	keep if filing_dt <= mdy(6,30,tax_yr+1)

	* Keep original filing or earliest correction if original not availbale
	bys npwp tax_yr: egen mincorrection = min(correction)
	drop if correction!=mincorrection
	
	* If still duplicates, keep earliest
	bys npwp tax_yr: egen mindate = min(system_dt)
	drop if system_dt!=mindate
	
	* Else randomly pick one
	gen double temprand = runiform()
	sort npwp tax_yr temprand
	by npwp tax_yr: gen ord = _n
	keep if ord==1
	isid npwp tax_yr
	
	drop mindate filing_dt system_dt mincorrection temprand ord
	
	ren tax_yr year
	
	local graphmin = 2003
	local graphmax = 2011
	keep if inrange(year,`graphmin', `graphmax')
	
	* Marginal tax rates pre-reform (schedule based on taxable income)
	gen mrate = .
	replace mrate = .10 if year<2009 & tincome<=.05			
	replace mrate = .15 if year<2009 & tincome>0.05 & tincome<=.1
	replace mrate = .30 if year<2009 & tincome>0.1 & !missing(tincome)
	
	* Marginal tax rates post-reform (schedule based on gross income)
	
	* Taxpayers below 4.8 and above 50
	replace mrate = .5*.28 if year==2009 & gincome<=4.8
	replace mrate = .5*.25 if year>=2010 & gincome<=4.8
	replace mrate = .28 if year==2009 & gincome>50 & !missing(gincome)
	replace mrate = .25 if year>=2010 & gincome>50 & !missing(gincome)
	
	* Taxpayers between 4.8 and 50
	gen tau1 		= .5*.28 if year==2009
	replace tau1	= .5*.25 if year>=2010
	gen tau2 		= .28 if year==2009
	replace tau2	= .25 if year>=2010
	
	replace mrate = tau1*4.8/gincome + tau2*(1- 4.8/gincome) if year>=2009 & gincome>4.8 & gincome<=50
	
	* MTR should not be defined if defining criterion don't exist
	assert missing(mrate) if (missing(tincome) & year<2008) | (missing(gincome) & year>=2009)
	
	drop tau1 tau2
	
	* Actual average rate
	gen double avgrate = round(totcitdue/tincome,0.01) if tincome>0 & totcitdue>0 & !missing(tincome) & !missing(totcitdue)
	
	* Keep if positive taxable income
	keep if tincome>0
	
	*********** Graph ***********
	
	* Merge dummy if taxpayer is in analysis sample
	preserve
		u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
		keep npwp
		duplicates drop
		tempfile ansamp
		sa `ansamp'
	restore
	
	merge m:1 npwp using `ansamp'
	keep if _merge==1 | _merge==3
	gen analysis_sample = (_merge==3)
	drop _merge
	
	gen period = ""
	replace period = "pre" if year<=2008
	replace period = "post" if year>=2010
	
	foreach period in pre post{
		count if period=="`period'" & gincome<100 
		local obs`period'  = r(N)
	}
	
	**********************************************
	************ Gross income graphs *************
	**********************************************
	
	* Gross income billion bins
	egen bingincome = cut(gincome), at(0(1)100)
	collapse (mean) avgrate ///
			 (mean) mrate ///
			 (count) npwp, by(bingincome period)

	gen double density =.
	foreach period in pre post{
		replace density = npwp/`obs`period'' if  period=="`period'"
	}
	replace density = density*100
	
	local tpre = "before"
	local tpost = "after"

	foreach period in pre post{
		* Density at new system gross income notch
			twoway (scatter npwp bingincome, yaxis(1)) (scatter density bingincome, yaxis(2)) ///
			if period=="`period'" & (bingincome>40 & bingincome <60), ///
			scheme(s1mono) xline(50) ///
			xtitle("Firm gross income (IDR 1 billion bins)") ///
			ytitle("Number of taxpayers", axis(1)) ///
			ytitle("Percent of taxpayers", axis(2)) ///
			yscale(titlegap(*5)) ///
			legend(label(1 "Number of taxpayers") label(2 "Percent of taxpayers")) ///

			graph export "${output}/analysis/graphs/taxrates_taxpayer_density_atnotch_`t`period''2009_bygincome.eps", replace

	} /* Close gross income bins pre post graph*/
	
} /* Close effective schedules all */

	*********************************************************************
	************** Prepare ETI estimation analysis file *****************
	*********************************************************************

if `setup'==1{

	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
	keep if year>=${minyear} & year<=${maxyear}
	
	sum tincome
	gen double totcitdue_n = totcitdue
	replace totcitdue_n = 0 if missing(totcitdue_n)
	qui gen double ppH_2529_2223    	  		= ppH_2529_corp + ppH_22 + ppH_22_imp + ppH_23
	qui gen double ppH_CITpaid		  			= min(ppH_2529_2223, max(totcitdue_n,ppH_2529_corp))
	qui gen double ppH_CITpaid_adj		 		= ppH_CITpaid  - refund
	qui gen double ppH_total_adj				= ppH_total - refund
	qui gen double ppHN_total_adj				= ppHN_total - refund
	
	* Use 2006 size for employment because don't have 2008 employment data, 2007 is small too
	foreach var of varlist num_perm num_workers{
		bys npwp: egen t`var' = max(cond(year==2006,`var',.))
		replace `var' = t`var' if year==2008
		drop t`var'
	}
	
	* IV weights file does not have variable evermto. Define based on inMTO by 2008
	gen double evermto = inMTOby2008
	
	tab year evermto
	tab year evermto if !missing(eweight2)
	
	* Estimate ETI with no weights (w0) , entropy 2005 (e2), and IPW 2005 (w2)
	gen double w0 = 1
	ren eweight2 w1
	
	*****************************************************************
	**************** Marginal and average tax rates *****************
	*****************************************************************
		
	* Marginal tax rates pre-reform (schedule based on taxable income)
	gen mrate = .
	replace mrate = .10 if year<2009 & tincome<=.05			
	replace mrate = .15 if year<2009 & tincome>0.05 & tincome<=.1
	replace mrate = .30 if year<2009 & tincome>0.1 & !missing(tincome)
	
	* Marginal tax rates post-reform (schedule based on gross income)
	
	* Taxpayers below 4.8 and above 50
	replace mrate = .5*.28 if year==2009 & gincome<=4.8
	replace mrate = .5*.25 if year>=2010 & gincome<=4.8
	replace mrate = .28 if year==2009 & gincome>50 & !missing(gincome)
	replace mrate = .25 if year>=2010 & gincome>50 & !missing(gincome)
	
	* Taxpayers between 4.8 and 50
	gen tau1 		= .5*.28 if year==2009
	replace tau1	= .5*.25 if year>=2010
	gen tau2 		= .28 if year==2009
	replace tau2	= .25 if year>=2010
	
	replace mrate = tau1*4.8/gincome + tau2*(1- 4.8/gincome) if year>=2009 & gincome>4.8 & gincome<=50
	
	* MTR should not be defined if defining criterion don't exist
	assert missing(mrate) if (missing(tincome) & year<2008) | (missing(gincome) & year>=2009)
	
	drop tau1 tau2
	
	* Actual average rate
	gen double avgrate = round(totcitdue/tincome,0.01) if tincome>0 & totcitdue>0 & !missing(tincome) & !missing(totcitdue)
	
	keep if !missing(mrate)
	
	tempfile alleti
	sa `alleti'
	
	*********************************************************************************************
	******* 2. Manual cleaning and re-estimate matching weights for robustness regressions ******
	*********************************************************************************************
	
	*****************************************************************************
	*** First get subset of taxpayers with which weights will be re-estimated ***
	*****************************************************************************
	
	u `alleti', clear
	
	* For tax year change years only, not all years
		bys npwp: egen everzero = max(cond(tincome==0 & inrange(year,2008,2010),1,0))
		bys npwp: egen everneg = max(cond(tincome<0 & inrange(year,2008,2010),1,0))
		
		keep if everzero==0 
		keep if everneg==0
	
	gen double netmrate = 1- mrate
	foreach var of varlist tincome gincome  netmrate{
		* Levels
		bys npwp: gen double `var'_t1 = `var'[_n+1]
		gen double `var'_chng = `var'_t1 - `var'
		
		* Log
		gen double ln`var' = ln(`var')
		bys npwp: gen double ln`var'_t1 = ln`var'[_n+1]
		gen double ln`var'_chng = ln`var'_t1 - ln`var'
	}
	
	keep if !missing(lntincome) & !missing(lngincome)
	keep if !missing(lntincome_chng)
	keep if !missing(lnnetmrate_chng) 
	
	keep if inrange(year,2008,2009)
	bys npwp: egen miny = min(year)
	bys npwp: egen maxy = max(year)
	
	keep if miny==2008 & maxy==2009
	
	keep npwp
	duplicates drop
	tempfile npwpset
	sa `npwpset'
		
	*****************************************************************************
	
	u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}.dta", clear
	
	merge m:1 npwp using `npwpset', keep(3) nogen
	
	* Express Rp variables in billion Rp
	ds npwp selection_yr selection_mto year inMTOby* ///
	   kpp mto origin_kpp ontime corrected correction klu2 klu_1721, not
	
	di "`r(varlist)'"
	foreach var of varlist `r(varlist)'{
		replace `var' = `var'/10^9
	}
	
	* Summarize SPT 1771 after cleaning so we see what this looks like
	gen evermto = inMTOby2008
	do "${dofile}/analysis/auxiliary_SPT_1771_detailed_cleaning.do"		/* This drops obs if outlier or SPT 1771 incorrect filing issues */
	
	drop p9999* p0001* istop* isbot*
	drop evermto

	* Make aggregate variables
	egen double ppH_total = rowtotal(ppH*)
	egen double ppN_total = rowtotal(ppN*)
	gen double  ppHN_total = ppH_total + ppN_total

	order npwp selection_yr selection_mto year origin_kpp inMTOby2008 kpp mto 
	
	tempfile main
	sa `main'
	
	*************************************************************************
	******************** 3. Treatment probability estimation ****************
	*************************************************************************

	u `main', clear
	
	* Keep treatment and baseline data
	keep npwp year inMTOby2008 selection_mto selection_yr gincome ppHN_total tincome
	
	* Match 2008 Jakarta Barat selection using 2005 data
	replace selection_yr = 2007 if selection_yr==2008
	
	keep if inrange(year,2003,2005)
	
	* Note: since now restriction is that payments and filings be paid or filed
	* 		by June of following tax year, all data in the setup file has
	*		2003-2005 payment and filing dates prior to selection date
	
	gen double base =.
	replace base = selection_yr - year
	drop year
	
	reshape wide gincome ppHN_total tincome, i(npwp inMTOby2008 selection_mto selection_yr) j(base)
	
	*************************************************************************
	**************** Taxpayers in the same support **************************
	*************************************************************************
	
	forvalues base=2/4{
		foreach var in gincome ppHN_total{
			
			mat support`base'`var' = J(3,10,.)	
			forvalues i=0/1{
				qui egen double p975`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(97.5)
				qui egen double p025`var'`i' = pctile(`var'`base') if inMTOby2008==`i', p(2.5)
				
				qui sum p975`var'`i'
				local p975`var'`i' = `r(mean)'
				
				qui sum p025`var'`i'
				local p025`var'`i' = `r(mean)'
				
				mat support`base'`var'[`i'+1, 1] = `p025`var'`i''
				mat support`base'`var'[`i'+1, 2] = `p975`var'`i''
				mat support`base'`var'[`i'+1, 3] = `i'
			}
			
			gen double lb`var'`base' = max(`p025`var'1',`p025`var'0')		/* Lower bound of common support */
			gen double ub`var'`base' = min(`p975`var'1',`p975`var'0')		/* Upper bound of common support */
			
			mat support`base'`var'[3, 1]  = max(`p025`var'1',`p025`var'0')
			mat support`base'`var'[3, 2]  = min(`p975`var'1',`p975`var'0')
			
			preserve
				clear
				svmat support`base'`var'
				gen var = "`var'"
				gen baseyear = 2007-`base'
				ren support`base'`var'1 p025
				ren support`base'`var'2 p975
				ren support`base'`var'3 mto
				
				keep var mto  baseyear p025 p975
				order var baseyear mto  p025 p975 
				
				tempfile s`base'`var'
				save `s`base'`var''
			restore
		}	
		
		
		drop p975* p025*
	}
	
	gen double comsup2 = ( gincome2 > lbgincome2 & gincome2< ubgincome2 ) & ///
							( ppHN_total2 > lbppHN_total2 & ppHN_total2 < ubppHN_total2 ) & ///
							!missing(gincome2) & !missing(ppHN_total2)
							
	drop lb* ub*
	
	******************* Entropy balancing weights *******************
	
	* Selection MTO 
	qui tab selection_mto, gen(fe_r)
	
	* 2005 entropy weights		(base 2)
	ebalance inMTOby2008 gincome2  ///
					 ppHN_total2 fe_r* if comsup2==1, ///
	targets(1) generate(eweight2)
	
	keep npwp eweight*
	duplicates drop
	renvars eweight*, pref(eti_)
	
	saveold "${output}/analysis/ETI_weights_${minyear}_${maxyear}.dta", replace
	
	**************************************************
	****** Merge estimated scores with main file *****
	**************************************************

	u `alleti', clear
	merge m:1 npwp using "${output}/analysis/ETI_weights_${minyear}_${maxyear}.dta", ///
	keep(1 3) nogen keepusing(eti_eweight2)
	
	cap drop w2
	ren eti_eweight2 w2
	
	* Estimate elasticity of taxable income with respect to marginal tax rate changes
	
	* Flag ever-zero and ever-negative
	bys npwp: egen everzero = max(cond(tincome==0 & inrange(year,2008,2010),1,0))
	bys npwp: egen everneg = max(cond(tincome<0 & inrange(year,2008,2010),1,0))
	gen mainsamp = (everzero==0 & everneg==0)
	
	**************************************
	*** Instruments and log variables ****
	**************************************
	
	* Base and forward years
	xtset npwp year
	tsfill, full
	
	* Actual net of tax rate
	gen double netmrate 		= 1 - mrate
	
	***********************************************************************
	*** Instrument for rate change: new schedule applied to 2008 gincome **
	***********************************************************************
	
	preserve
		keep if inrange(year,2008,2010)
		
		gen mratehat_n =.
		
		* Weights for MTR non-linear schedule
		
			* 2008 instrument rate (same as actual)
			replace mratehat_n = mrate if year==2008
		
			* 2008-2009 schedule change
			gen tau1 		= .5*.28 	if year==2009	
			gen tau2 		= .28 		if year==2009
			
			* 2009-2010 tax cut
			replace tau1	= .5*.25 	if year>=2010
			replace tau2	= .25 		if year>=2010
		
		* Predicted MTR based on 2008 gross income
		
			bys npwp: egen double gincome2008 = max(cond(year==2008,gincome,.))
		
			* Below 4.8 gross income
			replace mratehat_n = tau1 ///
			if gincome2008<=4.8 & year>=2009
			
			* Above 4.8 gross income
			replace mratehat_n = tau2 ///
			if gincome2008>50 & !missing(gincome2008) & year>=2009
			
			* Between 4.8 and 50
			replace mratehat_n = tau1*4.8/gincome2008 + tau2*(1- 4.8/gincome2008) ///
			if gincome2008>4.8 & gincome2008<=50 & year>=2009
		
		* Net
			gen double netmratehat_n = 1-mratehat_n
			
			drop tau1 tau2
			
			keep npwp year netmratehat_n mratehat_n
			duplicates drop
			
			tempfile inst
			sa `inst'
	restore
	
	* Alternative instrument for robustness, using lagged (2007) data to apply new schedule
	preserve
		keep if inrange(year,2007,2010)
		gen mratehat_n2007 =.
		
		foreach var of varlist tincome gincome{
			`tools'bys npwp: egen double `var'2007 = max(cond(year==2007, `var',.))
		}
		
		* Weights for MTR non-linear schedule
		
			* 2008 instrument rate (same as actual)
			replace mratehat_n2007 = mrate if year==2008
		
			* 2008-2009 schedule change
			gen tau1 		= .5*.28 	if year==2009	
			gen tau2 		= .28 		if year==2009
			
			* 2009-2010 tax cut
			replace tau1	= .5*.25 	if year>=2010
			replace tau2	= .25 		if year>=2010
		
		* Predicted MTR based on 2007 gross income
		
			* Below 4.8 gross income
			replace mratehat_n2007 = tau1 ///
			if gincome2007<=4.8 & year>=2009
			
			* Above 4.8 gross income
			replace mratehat_n2007 = tau2 ///
			if gincome2007>50 & !missing(gincome2007) & year>=2009
			
			* Between 4.8 and 50
			replace mratehat_n2007 = tau1*4.8/gincome2007 + tau2*(1- 4.8/gincome2007) ///
			if gincome2007>4.8 & gincome2007<=50 & year>=2009
		
		* Net
			gen double netmratehat_n2007 = 1-mratehat_n2007
			
			drop tau1 tau2
			
			gen double lntincome2007= ln(tincome2007)
			gen double lngincome2007 = ln(gincome2007)
			
			keep npwp year netmratehat_n2007 lntincome2007 lngincome2007
			duplicates drop
			
			tempfile reversion
			sa `reversion'
	restore
	
	* Tag 2007-2010 balanced sample for robustness
	preserve
		keep if inrange(year,2007,2010)
		
		foreach var of varlist tincome gincome{
			gen double ln`var' = ln(`var')
			bys npwp: gen double ln`var'lag = ln`var'[_n-1]
		}
		
		keep if ( !missing(lntincome) & !missing(lntincomelag) & !missing(lngincomelag) & year>=2008)  | ///
				( !missing(lntincome) & !missing(lngincome) & year==2007) 
				  
		cap drop lntincome lntincomelag lngincome lngincomelag
		
		bys npwp: egen double miny = min(year)
		bys npwp: egen double maxy = max(year)
		
		keep if miny==2007 & maxy==2010
		drop miny maxy
		
		keep npwp
		duplicates drop
		gen balanced_2007_2010 = 1
		tempfile balanced
		sa `balanced'
	restore
	
	* Log, forward log, and log change of actual and predicted
	sort npwp year
	xtset npwp year
	tsfill, full
	
	* Dummies for paid any or paid more than last year
	bys npwp: gen moretinc = tincome[_n+1] > tincome if !missing(tincome[_n+1]) & !missing(tincome)
	gen postinc = (tincome > 0 ) if !missing(tincome)
	bys npwp: gen postinc_t1 = (tincome[_n+1] > 0 ) if !missing(tincome[_n+1])
	gen anytinc_chng = postinc_t1 - postinc
	
	** Merge each set of instruments back ***
	keep if inrange(year,2008,2010)
	
	merge 1:1 npwp year using `inst', keep(1 3) nogen
	merge 1:1 npwp year using `reversion', keep(1 3) nogen
	merge m:1 npwp using `balanced', keepusing(balanced_2007_2010) keep(1 3) nogen
	replace balanced_2007_2010=0 if missing(balanced_2007_2010)
	
	foreach var of varlist ppN_total ppH_total_adj ppHN_total_adj tincome gincome ///
						   num_perm num_workers ppH_CITpaid_adj ///
						   mratehat_n netmratehat_n netmrate netmratehat_n2007{	
		
		* Levels
		bys npwp: gen double `var'_t1 = `var'[_n+1]
		gen double `var'_chng = `var'_t1 - `var'
		
		* Log
		gen double ln`var' = ln(`var')
		bys npwp: gen double ln`var'_t1 = ln`var'[_n+1]
		gen double ln`var'_chng = ln`var'_t1 - ln`var'
	}
	
	* Include zeros
	foreach var of varlist ppN_total ppH_total_adj ppHN_total_adj tincome gincome ///
						   num_perm num_workers ppH_CITpaid_adj{	
		
		* Log (`var'*10^9 + 1): back to billions plus 1
		gen double sn`var' = ln(`var'*10^9 + 1)
		bys npwp: gen double sn`var'_t1 = sn`var'[_n+1]
		gen double sn`var'_chng = sn`var'_t1 - sn`var'
	}
	
	*****************************
	***** Sample restriction ****
	*****************************
	
	keep if inrange(year,2008,2009)
	
	* Has endogenous variable
	keep if !missing(lnnetmrate) 
	order npwp year everzero everneg mainsamp
	saveold "${output}/analysis/ETI_analysisfile.dta", replace
}

	************************************************************
	************** ETI estimation specifications ***************
	************************************************************
	
if `analysis'==1{

	u "${output}/analysis/ETI_analysisfile.dta", clear
	
	/* Spec tracking: 
			
			lyear: 		last base year included in regression (2009 or 2008)
			controls:  	with controls (1) or without (0) or mean reversion (2)
			weight: 	none (0), original (1), re-estimated (2)
			FE:			taxpayer FE (1), industry FE (2)
			cut:		all (0), predicted cut (1), predicted raise (2), balanced 2007-2010 (3)
	*/
		
	**********************
	*** Homogenous ETI ***
	**********************
	
	local row = 1
	matrix etihomo 		= J(800,20,.)
	
	* Main specification
	
		ivreghdfe lntincome_chng lntincome lngincome  ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		local row = `row' + 2
	
	* Unweighted regression
	
		ivreghdfe lntincome_chng  lntincome lngincome  ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) ///
		if year<=2009 & mainsamp==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 0		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Re-estimated weights
	
		ivreghdfe lntincome_chng  lntincome lngincome  ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w2] ///
		if year<=2009 & mainsamp==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
			
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 2		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Restricting estimation to 2007-2010 balanced sample
	
		ivreghdfe lntincome_chng lntincome lngincome  ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1 & balanced_2007_2010==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 3		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Using lagged data for instrument and baseline controls (mean reversion spec)
		foreach var of varlist lntincome lngincome{
			bys npwp: gen double `var'lag = `var'[_n-1]
			replace `var'lag = `var'2007 if year==2008
		}
		
		ivreghdfe lntincome_chng lntincomelag lngincomelag  ///
		(lnnetmrate_chng  = lnnetmratehat_n2007_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n2007_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n2007_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 2		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* No taxpayer FE, industry FE + evermto instead
		ivreghdfe lntincome_chng  evermto lntincome lngincome  ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1, absorb(year klu2) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 2		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* No baseline controls
		ivreghdfe lntincome_chng    ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1, absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 0		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Using 2008-2009 change only
		ivreghdfe lntincome_chng  evermto  lntincome lngincome ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2008 & mainsamp==1, absorb(klu2) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2008	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 2		/* FE */
			mat etihomo[`row'+`j',9] 	= 0		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Taxpayers with predicted tax cut only
	
		gen double pos2008 =  (mratehat_n_chng >0)
		bys npwp: egen maxpos2008 = max(pos2008)
	
		ivreghdfe lntincome_chng  lntincome lngincome  (lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1 & maxpos2008==0, ///
		absorb(npwp year) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 1		/* cut */
		}
		
		
		local row = `row' + 2
		
	* Taxpayers with predicted tax raise only
	
		ivreghdfe lntincome_chng  lntincome lngincome  (lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & mainsamp==1 & maxpos2008==1, ///
		absorb(npwp year) cluster(npwp) savefirst
		
		*** Second stage ***
		mat etihomo[`row',1] = _b[lnnetmrate_chng]
		mat etihomo[`row'+1,1] = _se[lnnetmrate_chng]
		
		*** Store first stage ***
		mat first = e(first)
		estimates restore _ivreg2_lnnetmrate_chng
		
		* FS var 1
		mat etihomo[`row',2] = _b[lnnetmratehat_n_chng]
		mat etihomo[`row'+1,2] = _se[lnnetmratehat_n_chng]
		mat etihomo[`row',3] = first[4,1]
		mat etihomo[`row',4] = e(N)
		
		* Specification tracker
		foreach j in 0 1{
			mat etihomo[`row'+`j',5] 	= 2009	/* lyear */
			mat etihomo[`row'+`j',6] 	= 1		/* controls */
			mat etihomo[`row'+`j',7] 	= 1		/* weight */
			mat etihomo[`row'+`j',8] 	= 1		/* FE */
			mat etihomo[`row'+`j',9] 	= 2		/* cut */
		}
		
		
		local row = `row' + 2
	
		
	preserve
		clear
		svmat etihomo
		ren etihomo1 iv_netmtr
		ren etihomo2 fs_netmtr
		ren etihomo3 fs_F
		ren etihomo4 e_N
		ren etihomo5 lyear
		ren etihomo6 controls
		ren etihomo7 weight
		ren etihomo8 FE
		ren etihomo9 cut
		
		gen coeff = ""
		replace coeff = "b" if mod(_n,2)==1
		replace coeff = "se" if mod(_n,2)==0
		
		drop etihomo*

		order lyear controls weight FE cut coeff 
		keep if iv_netmtr!=.
		
		outsheet using "${output}/analysis/csv/etihomo.csv", comma replace
	restore
	
	**************************************
	*** Heterogenous ETI by MTO status ***
	**************************************
	
	foreach x in lntincome lngincome lntincome_chng lnnetmrate_chng lnnetmratehat_n_chng{
		gen double `x'evermto = `x'*evermto
		gen double `x'mto = `x'*mto
	}

	* Fixed effects
	egen double year_evermto = group(year evermto)
	egen double year_mto = group(year mto)
	
	matrix etisep 		= J(800,20,.)
	
	local row = 1
	
	* Joint regression used later for pval of difference
	* Tag taxpayers in this sample so same sample is used for robustness to weight and treatment definition
	 qui ivreghdfe lntincome_chng lntincome lngincome lntincomeevermto lngincomeevermto ///
				(lnnetmrate_chng lnnetmrate_chngevermto  = ///
				lnnetmratehat_n_chng lnnetmratehat_n_chngevermto ) [pw=w1] ///
				if year<=2009 & mainsamp==1, absorb(year_evermto npwp) cluster(npwp) savefirst
	 gen heterosamp = e(sample)
	
	** Loop through assigned vs actual mto status and weighted vs unweighted
	
	foreach treat in evermto mto{
		foreach weight in 0 1{
		
			mat s`treat'`weight' = J(4,5,.)
			
		* MTO estimate
			ivreghdfe lntincome_chng  lntincome lngincome  ///
			(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w`weight'] ///
			if year<=2009 & heterosamp==1 & `treat'==1, absorb(year npwp) cluster(npwp) savefirst
			
			*** Second stage ***
			mat s`treat'`weight'[`row',1] = _b[lnnetmrate_chng]
			mat s`treat'`weight'[`row'+1,1] = _se[lnnetmrate_chng]
			
			*** Store first stage ***
			mat first = e(first)
			estimates restore _ivreg2_lnnetmrate_chng
			
			* FS var 1
			mat s`treat'`weight'[`row',2] = _b[lnnetmratehat_n_chng]
			mat s`treat'`weight'[`row'+1,2] = _se[lnnetmratehat_n_chng]
			mat s`treat'`weight'[`row'+2,2] = first[4,1]
			mat s`treat'`weight'[`row'+3,2] = e(N)
			
		* Not MTO estimate
			ivreghdfe lntincome_chng  lntincome lngincome  ///
			(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w`weight'] ///
			if year<=2009 & heterosamp==1 & `treat'==0, absorb(year npwp) cluster(npwp) savefirst
			
			*** Second stage ***
			mat s`treat'`weight'[`row',3] = _b[lnnetmrate_chng]
			mat s`treat'`weight'[`row'+1,3] = _se[lnnetmrate_chng]
			
			*** Store first stage ***
			mat first = e(first)
			estimates restore _ivreg2_lnnetmrate_chng
			
			* FS var 1
			mat s`treat'`weight'[`row',4] = _b[lnnetmratehat_n_chng]
			mat s`treat'`weight'[`row'+1,4] = _se[lnnetmratehat_n_chng]
			mat s`treat'`weight'[`row'+2,4] = first[4,1]
			mat s`treat'`weight'[`row'+3,4] = e(N)
			
		* P-value for difference in coefficients (joint spec for testing)
			ivreghdfe lntincome_chng lntincome lngincome lntincome`treat' lngincome`treat' ///
					(lnnetmrate_chng lnnetmrate_chng`treat'  = ///
					lnnetmratehat_n_chng lnnetmratehat_n_chng`treat' ) [pw=w`weight'] ///
					if year<=2009 & heterosamp==1, absorb(year_`treat' npwp) cluster(npwp) savefirst
				
			* P-value of difference between MTO vs non-MTO
			test _b[lnnetmrate_chng]+_b[lnnetmrate_chng`treat' ] = _b[lnnetmrate_chng] 
			mat s`treat'`weight'[`row',5] 	= `r(p)'
		
		preserve
			clear
			svmat s`treat'`weight'
			ren s`treat'`weight'1 iv_netmtr_mto
			ren s`treat'`weight'2 fs_netmtr_mto

			ren s`treat'`weight'3 iv_netmtr_notmto
			ren s`treat'`weight'4 fs_netmtr_notmto
			ren s`treat'`weight'5 pval_diff
			
			gen coeff = ""
			replace coeff = "b" if _n==1
			replace coeff = "se" if _n==2
			replace coeff = "F" if _n==3
			replace coeff = "N" if _n==4
			
			gen treat = "`treat'"
			gen weight = "w`weight'"
			
			keep if coeff!=""
			
			order treat weight coeff
			
			tempfile f`treat'`weight'
			sa `f`treat'`weight''
		restore
	} /* Close weight */
	} /* Close treat */
	
	preserve
		u `fevermto0', clear
		foreach treat in evermto mto{
			foreach weight in 0 1{
				append using `f`treat'`weight''
			}
		}
		duplicates drop
		outsheet using "${output}/analysis/csv/etisep.csv", comma replace
	restore
	
	************************************************************
	******* Additional outcomes regressed on MTR ***************
	************************************************************

	local row = 1
	
	* Interactions
	foreach x in lntincome lngincome sntincome sngincome lnnetmrate_chng lnnetmratehat_n_chng{
		cap gen double `x'MTO = `x'*evermto
	}
	
	foreach outcome in moretinc anytinc_chng lngincome_chng ///
					lnnum_perm_chng lnnum_workers_chng ///
					lnppH_CITpaid_adj_chng lnppH_total_adj_chng ///
					lnppN_total_chng lntincome_chng{
		
		* MTO interaction for outcome baseline control
		local ocontrol 		= subinstr("`outcome'","_chng","",.)
		cap drop `ocontrol'MTO
		cap gen double `ocontrol'MTO = `ocontrol'*evermto
		local ocontrolMTO 	= "`ocontrol'MTO"
		
		mat c`outcome' = J(3,4,.)
		
		if "`outcome'"=="moretinc" | "`outcome'"=="lngincome_chng" | "`outcome'"=="lntincome_chng" {
			local mcontrol 		"lntincome lngincome"
			local mcontrolMTO	"lntincomeMTO lngincomeMTO"
			local ocontrol ""
			local ocontrolMTO ""
			local condition "& mainsamp==1"
			local conditionhet "& heterosamp==1"
		}
		* This spec includes zeros, so no conditioning on mainsamp==1
		else if  "`outcome'"=="anytinc_chng"{
			local mcontrol 	"sntincome sngincome"
			local mcontrolMTO "sntincomeMTO sngincomeMTO"
			local ocontrol ""
			local ocontrolMTO ""
			local condition ""
			local conditionhet ""
		}
		else{
			local condition 	"& mainsamp==1"
			local conditionhet  "& heterosamp==1"
			local mcontrol 		"lntincome lngincome"
			local mcontrolMTO	"lntincomeMTO lngincomeMTO"
		}
		
		* Main
		ivreghdfe `outcome'  `mcontrol' `ocontrol' ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 `condition', absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat c`outcome'[`row',1] = _b[lnnetmrate_chng]
		mat c`outcome'[`row'+1,1] = _se[lnnetmrate_chng]
		mat c`outcome'[`row'+2,1] = e(N)
		
		* MTO only
		ivreghdfe `outcome'  `mcontrol' `ocontrol' ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & evermto==1 `conditionhet', absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat c`outcome'[`row',2] = _b[lnnetmrate_chng]
		mat c`outcome'[`row'+1,2] = _se[lnnetmrate_chng]
		mat c`outcome'[`row'+2,2] = e(N)
		
		* Not MTO
		ivreghdfe `outcome'  `mcontrol' `ocontrol' ///
		(lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] ///
		if year<=2009 & evermto==0 `conditionhet', absorb(year npwp) cluster(npwp) savefirst
		
		*** Second stage ***
		mat c`outcome'[`row',3] = _b[lnnetmrate_chng]
		mat c`outcome'[`row'+1,3] = _se[lnnetmrate_chng]
		mat c`outcome'[`row'+2,3] = e(N)
		
		* P-value of difference
		ivreghdfe `outcome' `mcontrol' `mcontrolMTO' `ocontrol' `ocontrolMTO'  ///
				(lnnetmrate_chng lnnetmrate_chngMTO  = ///
				lnnetmratehat_n_chng lnnetmratehat_n_chngMTO ) [pw=w1] ///
				if year<=2009 `conditionhet', absorb(year_evermto npwp) cluster(npwp) savefirst
			
		* P-value of difference between MTO vs non-MTO
		test _b[lnnetmrate_chng]+_b[lnnetmrate_chngMTO] = _b[lnnetmrate_chng] 
		mat c`outcome'[`row',4] 	= `r(p)'
		
		preserve
			clear
			svmat c`outcome'
			
			ren c`outcome'1 pooled
			ren c`outcome'2 MTO
			ren c`outcome'3 notMTO
			ren c`outcome'4 pval
			
			gen stat = ""
			replace stat = "b" if _n==1
			replace stat = "se" if _n==2
			replace stat = "N"  if _n==3
			
			gen outcome = "`outcome'"
			
			keep if !missing(pooled)
			order outcome stat
			tempfile f`outcome'
			sa `f`outcome''
		restore
	}
	
	* Append all
	u `fanytinc_chng', clear
	foreach outcome in anytinc_chng lngincome_chng ///
					lnnum_perm_chng lnnum_workers_chng ///
					lnppH_CITpaid_adj_chng lnppH_total_adj_chng ///
					lnppN_total_chng lntincome_chng moretinc{
						
		append using `f`outcome''
	}
						
	outsheet using "${output}/analysis/csv/mtrmore.csv", comma replace

}	/* Close actual data analysis*/
clear
log close
