* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/5_4_ETI_estimation_robustness_2008_2010_difference.log", replace
di in red "Run 5_4_ETI_estimation_robustness_2008_2010_difference.do"

global minyear  = 2003
global maxyear  = 2011

	
**************************************************************************************
*** Re-build ETI estimation file but keeping 2008 and 2010 only for long-difference **
**************************************************************************************

u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
keep if year>=${minyear} & year<=${maxyear}

* Use 2006 size for employment because don't have 2008 employment data, 2007 is small too
foreach var of varlist num_perm num_workers{
	bys npwp: egen t`var' = max(cond(year==2006,`var',.))
	gen double ln`var' = ln(`var')
	replace ln`var' = ln(t`var') if year==2008
	drop t`var'
}

* IV weights file does not have variable evermto. Define based on inMTO by 2008
gen double evermto = inMTOby2008

tab year evermto
tab year evermto if !missing(eweight2)

* Estimate ETI with no weights (w0) , entropy 2005 (e2), and IPW 2005 (w2)
gen double w0 = 1
ren eweight2 w1

*****************************************************************
**************** Marginal and average tax rates *****************
*****************************************************************
	
* Marginal tax rates pre-reform (schedule based on taxable income)
gen mrate = .
replace mrate = .10 if year<2009 & tincome<=.05			
replace mrate = .15 if year<2009 & tincome>0.05 & tincome<=.1
replace mrate = .30 if year<2009 & tincome>0.1 & !missing(tincome)

* Marginal tax rates post-reform (schedule based on gross income)

* Taxpayers below 4.8 and above 50
replace mrate = .5*.28 if year==2009 & gincome<=4.8
replace mrate = .5*.25 if year>=2010 & gincome<=4.8
replace mrate = .28 if year==2009 & gincome>50 & !missing(gincome)
replace mrate = .25 if year>=2010 & gincome>50 & !missing(gincome)

* Taxpayers between 4.8 and 50
gen tau1 		= .5*.28 if year==2009
replace tau1	= .5*.25 if year>=2010
gen tau2 		= .28 if year==2009
replace tau2	= .25 if year>=2010

replace mrate = tau1*4.8/gincome + tau2*(1- 4.8/gincome) if year>=2009 & gincome>4.8 & gincome<=50

* MTR should not be defined if defining criterion don't exist
assert missing(mrate) if (missing(tincome) & year<2008) | (missing(gincome) & year>=2009)

drop tau1 tau2

* Actual average rate
gen double avgrate = round(totcitdue/tincome,0.01) if tincome>0 & totcitdue>0 & !missing(tincome) & !missing(totcitdue)

keep if !missing(mrate)

merge m:1 npwp using "${output}/analysis/ETI_weights_${minyear}_${maxyear}.dta", ///
keep(1 3) nogen keepusing(eti_eweight2)

cap drop w2
ren eti_eweight2 w2

* Estimate elasticity of taxable income
* with respect to marginal tax rate changes

* Restrict to positive taxable income
bys npwp: egen everzero = max(cond(tincome==0 & inrange(year,2008,2010),1,0))
bys npwp: egen everneg = max(cond(tincome<0 & inrange(year,2008,2010),1,0))

keep if everzero==0 
keep if everneg==0

**************************************
* Taxable income and net of tax rate *
**************************************

* Base and forward years
xtset npwp year
tsfill, full

* Actual net of tax rate
gen double netmrate 		= 1 - mrate

bys npwp: egen double gincome2008 = max(cond(year==2008,gincome,.))

****************************************************************************
******************** Robustness: Keep only years 2008 and 2010 *************
****************************************************************************
keep if inlist(year,2008,2010)

gen mratehat_n =.
gen tau1 = .
gen tau2 = .

* Weights for MTR non-linear schedule
	
	* 2008 instrument rate (same as actual)
	replace mratehat_n = mrate if year==2008
	
	* 2009-2010 tax cut
	replace tau1	= .5*.25 	if year>=2010
	replace tau2	= .25 		if year>=2010

* Predicted MTR based on 2008 gross income

	* Below 4.8 gross income
	replace mratehat_n = tau1 ///
	if gincome2008<=4.8 & year>=2010
	
	* Above 4.8 gross income
	replace mratehat_n = tau2 ///
	if gincome2008>50 & !missing(gincome2008) & year>=2010
	
	* Between 4.8 and 50
	replace mratehat_n = tau1*4.8/gincome2008 + tau2*(1- 4.8/gincome2008) ///
	if gincome2008>4.8 & gincome2008<=50 & year>=2010

* Net
	gen double netmratehat_n = 1-mratehat_n
	
	drop tau1 tau2
	
*******************************************************************
* Predicted MTR change instrument (predicted next/current actual) *
*******************************************************************

* Log, forward log, and log change of actual and predicted
sort npwp year

foreach var of varlist tincome gincome netmrate netmratehat_n{	
	
	* Levels
	bys npwp: gen double `var'_t1 = `var'[_n+1]
	gen double `var'_chng = `var'_t1 - `var'
	
	* Log
	gen double ln`var' = ln(`var')
	bys npwp: gen double ln`var'_t1 = ln`var'[_n+1]
	gen double ln`var'_chng = ln`var'_t1 - ln`var'
}

*****************************
***** Sample restriction ****
*****************************

keep if year==2008

* Regression
ivreghdfe lntincome_chng evermto lngincome lntincome (lnnetmrate_chng = lnnetmratehat_n_chng) [pw=w1], absorb(klu2) cluster(npwp) savefirst

mat IV = (_b[lnnetmrate_chng], _se[lnnetmrate_chng], e(N))
mat first = e(first)
local fs = first[4,1]
estimates restore _ivreg2_lnnetmrate_chng
mat FS = (_b[lnnetmratehat_n_chng], _se[lnnetmratehat_n_chng], `fs')

mat results = IV \ FS

clear
svmat results
ren results1 b
ren results2 se
ren results3 e_N_F

gen spec = ""
replace spec = "IV" if _n==1
replace spec = "FS" if _n==2
order spec

outsheet using "${output}/analysis/csv/ETI_2008_vs_2010.csv", comma replace
		
clear
log close
