* All analyses are based on anonymized data
* Variable "npwp" is a randomly generated taxpayer ID
set seed 98765
log using "${dofile}/logs/5_3_ETI_trend_graphs.log", replace
di in red "Run 5_3_ETI_trend_graphs.do"

global minyear  = 2003
global maxyear  = 2011

local eti_estimation			= 1
local revision_trends			= 1

	****************************************************************************
	****************** Estimation of elasticities ******************************
	****************************************************************************

if `eti_estimation'==1{

		u "${output}/analysis/MTO_analysisfile_${minyear}_${maxyear}_addoutcomes.dta", clear
		keep if year>=${minyear} & year<=${maxyear}

		* IV weights file does not have variable evermto. Define based on inMTO by 2008
		gen double evermto = inMTOby2008
		
		tab year evermto
		tab year evermto if !missing(eweight2)
		
		* Estimate ETI with no weights (w0) , entropy 2005 (e2), and IPW 2005 (w2)
		gen double w0 = 1
		ren eweight2 w1
		
		*****************************************************************
		**************** Marginal and average tax rates *****************
		*****************************************************************

		* Marginal tax rates pre-reform (schedule based on taxable income)
		gen mrate = .
		replace mrate = .10 if year<2009 & tincome<=.05	
		replace mrate = .15 if year<2009 & tincome>0.05 & tincome<=.1
		replace mrate = .30 if year<2009 & tincome>0.1 & !missing(tincome)
		
		* Marginal tax rates post-reform (schedule based on gross income)
		
		* Taxpayers below 4.8 and above 50
		replace mrate = .5*.28 if year==2009 & gincome<=4.8 
		replace mrate = .5*.25 if year>=2010 & gincome<=4.8
		replace mrate = .28 if year==2009 & gincome>50 & !missing(gincome) 
		replace mrate = .25 if year>=2010 & gincome>50 & !missing(gincome) 
		
		* Taxpayers between 4.8 and 50
		gen tau1 		= .5*.28 if year==2009 
		replace tau1	= .5*.25 if year>=2010 
		gen tau2 		= .28 if year==2009 
		replace tau2	= .25 if year>=2010 
		
		replace mrate = tau1*4.8/gincome + tau2*(1- 4.8/gincome) if year>=2009 & gincome>4.8 & gincome<=50 
		
		* MTR should not be defined if defining criterion don't exist
		assert missing(mrate) if (missing(tincome) & year<2008) | (missing(gincome) & year>=2009)
		
		drop tau1 tau2
		
		* Actual average rate
		gen double avgrate = round(totcitdue/tincome,0.01) if tincome>0 & totcitdue>0 & !missing(tincome) & !missing(totcitdue)
		
		keep if !missing(mrate)
		
		tempfile alleti
		sa `alleti'
		
		merge m:1 npwp using "${output}/analysis/ETI_weights_${minyear}_${maxyear}.dta", ///
		keep(1 3) nogen keepusing(eti_eweight2)
		
		cap drop w2
		ren eti_eweight2 w2
		
		* Estimate elasticity of taxable income
		* with respect to marginal tax rate changes
		
		* Restrict to positive taxable income
		bys npwp: egen everzero = max(cond(tincome==0 & inrange(year,2008,2010),1,0))
		bys npwp: egen everneg = max(cond(tincome<0 & inrange(year,2008,2010),1,0))
		
		**************************************
		* Taxable income and net of tax rate *
		**************************************
		
		* Base and forward years
		xtset npwp year
		tsfill, full
		
		* Actual net of tax rate
		gen double netmrate 		= 1 - mrate
		
		**********************************************************************
		*** Instrument for rate change: new schedule applied to 2008 gincome **
		**********************************************************************
		
		* From now on, keep if year is on or after 2008
		keep if inrange(year,2005,2010)
		
		* Weights for MTR non-linear schedule
		
		* 2008-2009 schedule change
		gen tau1 		= .5*.28 	if year==2009	
		gen tau2 		= .28 		if year==2009
		
		* 2009-2010 tax cut
		replace tau1	= .5*.25 	if year>=2010
		replace tau2	= .25 		if year>=2010
		
		*Base year
		gen mratehat_n =.

		* 2008 instrument rate (same as actual)
			replace mratehat_n = mrate if year==2008
			
		* Predicted MTR based on base year gross income
			bys npwp: egen double gincome2008 = max(cond(year==2008,gincome,.))
		
			* Below 4.8 gross income
			replace mratehat_n = tau1 ///
			if gincome2008<=4.8 & year>=2009
			
			* Above 4.8 gross income
			replace mratehat_n = tau2 ///
			if gincome2008>50 & !missing(gincome2008) & year>=2009
			
			* Between 4.8 and 50
			replace mratehat_n = tau1*4.8/gincome2008 + tau2*(1- 4.8/gincome2008) ///
			if gincome2008>4.8 & gincome2008<=50 & year>=2009
			
			* Net
			gen double netmratehat_n = 1-mratehat_n
		
		bys npwp: egen double tincome2008 = max(cond(year==2008,tincome,.))
		
		drop tau1 tau2
		
		tempfile ratehat
		sa `ratehat'
		
		*******************************************************************
		* Predicted MTR change instrument (predicted next/current actual) *
		*******************************************************************
		
		* Log, forward log, and log change of actual and predicted
		sort npwp year
		
		foreach var of varlist tincome gincome ///
							   mrate netmrate ///
							   netmratehat_n mratehat_n{	
			
			* Levels
			bys npwp: gen double `var'_t1 = `var'[_n+1]
			gen double `var'_chng = `var'_t1 - `var'
			
			* Log
			gen double ln`var' = ln(`var')
			bys npwp: gen double ln`var'_t1 = ln`var'[_n+1]
			gen double ln`var'_chng = ln`var'_t1 - ln`var'
		}
	
		* Has endogenous variable
		keep if !missing(lnnetmrate) 
		
		***********************************************************
		***** ETI estimation sample is restricted to key years ****
		***********************************************************
		
		keep if inrange(year,2008,2009)

		tempfile etiestsample
		sa `etiestsample'
		
		* Distribution of tax raise for taxpayers experiecing tax raise
		
		preserve
			keep if year ==2008 & mratehat_n_chng>0
			collapse (p90) p90raise = mratehat_n_chng ///
					 (p91) p91raise = mratehat_n_chng ///
					 (p92) p92raise = mratehat_n_chng ///
					 (p93) p93raise = mratehat_n_chng ///
					 (p94) p94raise = mratehat_n_chng ///
					 (p95) p95raise = mratehat_n_chng
			outsheet using "${output}/analysis/csv/mtr_raise_pctiles.csv", comma replace
		restore
	
	**************************************************************************
	************ Revision trend graphs for 2008-2009 change ******************
	**************************************************************************
	
	if `revision_trends'==1{
		
		global gminyear = 2005
		global gmaxyear = 2011
		
		** Tag NPWPS in main ETI estimation sample ***
		u `etiestsample', clear
		ren lnnetmratehat_n_chng lnnetmratehat_n_chng
		di "Main ETI specification (both years)"
		ivreghdfe lntincome_chng  lntincome lngincome  (lnnetmrate_chng  = lnnetmratehat_n_chng) [pw=w1] if year<=2009, absorb(npwp year) cluster(npwp) first
		gen homosample = e(sample)
		
		preserve
			keep if homosample==1
			keep npwp 
			gduplicates drop
			tempfile etinpwps
			sa `etinpwps'
		restore
		
		***** Now get data for all years for graphs *****
		u `alleti', clear
		keep if inrange(year, ${gminyear},${gmaxyear})
		tempfile galleti
		sa `galleti'
		
		* Split sample based on predicted tax change for first year of reform
		* With different estimates depending on base year used
		u `ratehat', clear
		
		* Restrict to taxpayers in ETI sample
		di "Plot only observations in the analysis sample"
		merge m:1 npwp using `etinpwps', keep(3) nogen		

		keep if year==2008 | year==2009
		sort npwp year
		
		bys npwp: gen double mrate_chng = mrate[_n+1] - mrate
		bys npwp: gen double mratehat_n_chng = mratehat_n[_n+1] - mratehat_n
	
		keep if year == 2008 & !missing(mratehat_n_chng) & !missing(mrate_chng)
		
		gen double lntincome = ln(tincome*10^9)			
		gen double lngincome = ln(gincome*10^9)
	
		cap drop gincome2008 
		cap drop tincome2008
		gen double lngincome2008 =lngincome
		gen double lntincome2008 =lntincome

		keep npwp mrate_chng mratehat_n_chng  lngincome2008 lntincome2008
		
		*********************************************************************
		************ Predicted tax rate change groups for graphs ************
		*********************************************************************
		
		*************** Condition on tax cut ****************
		keep if mratehat_n_chng<0
		sort mratehat_n_chng
		gen rank = _n
		count
		
		gen rg2 = ""
		replace rg2 =  "g2_p1" if (rank <= `r(N)'/2)
		replace rg2 =  "g2_p2" if rg2==""
		
		* Store average predicted change of each rg in locals for graphs
		foreach g in 2 {
			forvalues i=1/`g'{
				sum mratehat_n_chng if rg`g'=="g`g'_p`i'"
				local rg`g'_p`i' = int(`r(mean)'*100)
			}
		}
		
		*********************************************************************
		************ Actual tax rate change rgs for graphs ************
		*********************************************************************

		* Merge back data for other years - sample includes only the taxpayers
		* used in the ETI estimation, with nonmissing data for mratehat_n_chng and res_mratehat
		merge 1:m npwp using `galleti', keep(3) nogen
	
		xtset npwp year
		tsfill
		
		* Fill in with 2008 info missing pre-years
		foreach var of varlist lngincome2008 lntincome2008 {
			bys npwp: egen double max`var' = max(`var')
			replace `var' = max`var' if missing(`var')
			drop max`var'
		}

		* Replace missing values with respective categories.
		* Some are strings so merge back
		di "Merge categories to all observations"
		preserve
			keep if year==2008
			keep npwp rg* mratehat_n_chng mrate_chng
			gduplicates drop
			tempfile x
			sa `x'
		restore
		merge m:1 npwp using `x', update replace keep(3 4 5) nogen
		
		*** Variable times year FE */
		forvalues y=2005/2011{
			gen fe_`y' = (year==`y')
			gen fe_`y'_p1 = (year==`y')*(rg=="g2_p1")
			gen double lngincome2008_t`y' = lngincome2008*(year==`y')
			gen double lntincome2008_t`y' = lntincome2008*(year==`y')

		}
		
		gen double lntincome = ln(tincome)
		renvars fe_2008*, pref(om_)
		gen one = 1
		
		tempfile all
		sa `all'
		local mrate "Marginal Tax Rate"
		local lntincome "Log taxable income"
		
		local mratelabel "ylabel(-0.15(0.05)0.05)"
		local lntincomelabel "ylabel(-0.10(0.05)0.40)"
			
		foreach outcome in mrate lntincome{
			estimates clear
			u `all', clear

			********************************************************************************
			****** Mrate difference between predicted large cut vs. small cut (Pooled) *****
			********************************************************************************
			
			ivreghdfe `outcome' fe_*_p1 fe_????  ln*_t2005 ln*_t2006 ln*_t2007 ln*_t2009 ln*_t2010 ln*_t2011 [pw=w1], absorb(i.npwp) cluster(npwp)
			
			mat b = e(b)[1,1..6]'
			mata st_matrix("se",sqrt(diagonal(st_matrix("e(V)"))))
			mat se = se[1..6,1]
			
			preserve
				clear
				svmat b
				svmat se
				ren b1 b
				ren se1 se
				gen double ll = b-1.96*se
				gen double ul = b+1.96*se
				gen year = _n + 2004
				replace year = year+1 if year>=2008
				expand 2 in 1
				count
				replace year = 2008 if _n==`r(N)'
				foreach var of varlist b ll ul{
					replace `var' = 0 if year==2008
				}
				
				sort year
				twoway  (rarea ll ul year, sort lwidth(none) color(gs8%30)) ///
						(connected b year, lpattern(solid) color(black) msize(small) msymbol(O)), ///
				scheme(s1mono)  yline(0, lpattern(dash) lcolor(gs10)) ///
				ytitle("``outcome''", size(medium)) yscale(titlegap(*5)) ``outcome'label' ///
				xtitle("Tax Year") xlabel(2005(1)2011) legend(off) 
				graph export "${output}/analysis/graphs/eti_DD_`outcome'.pdf", replace
			restore
		} /* Close var */

	} /* Close trend graphs */	
	
}	/* Close actual data analysis*/
clear
log close
