/*
	Code for detailed manual cleaning of SPT 1771 variables.
	Variables should already be in billion Rp before running this code
	
	All analyses are based on anonymized data
	Variable "npwp" is a randomly generated taxpayer ID
	
*/

 *******************************************************************************
 ******* First, check for important data entry mistakes according to SPT 1771 **
 ********************* Taxpayer form instructions ******************************
 *******************************************************************************
	
	* Clean versions
	foreach var of varlist ///
		totcitdue citdue tincome adjforcred nincome comploss ///
		nincbus gincome cgsold otherexpense 	///
		totcomninc nincsidebus    ///
		forcomninc domcomninc  ntaxinc facilityinv ///
		totposadj     totnegadj{
			
			qui gen double `var'_fix = `var'
	}
 
	* Page 12: Taxpayer should fill out comploss as zero if Fiscal net income was negative
	* Page 26: If fiscal net income is negative, not necessary to fill out anything else
	* because no taxes are due. Taxable income and total taxes due should be zero.
	sum nincome tincome comploss, detail
	
	replace comploss_fix 	= 0 if comploss!=0 & nincome<=0
	replace tincome_fix  	= 0 if tincome<0
	replace citdue_fix   	= 0 if citdue<0
	replace totcitdue_fix 	= 0 if totcitdue<0
	
	* unique npwp if comploss<0
	* 89 taxpayers report negative comploss
	* br npwp tincome nincome comploss if  comploss<0
	* Looks like those should be positive based on tincome values
	replace comploss_fix = abs(comploss) if comploss<0
	
	* Pages 5 and 6: Adjustments
	* For a handfull of observations these are entered as negative. Unclear why. 
	* Drop observation if negative
	sum totposadj totnegadj, detail
	unique npwp if totposadj<0 & evermto==1
	unique npwp if totnegadj<0 & evermto==1
	
	* br npwp nincome totcomninc  ntaxinc totposadj totnegadj if totposadj<0
	drop if totposadj<0 | totnegadj<0 | ntaxinc<0
	
	* Page 4 Cost of sales and other expenses.
	* These should never be reported as negative
	unique npwp if cgsold<0 | otherexpense<0 | ntaxinc<0
	drop if cgsold <0 | otherexpense<0 | ntaxinc<0
	*br nincbus gincome otherexpense  cgsold if otherexpense<0
		
 *******************************************************************************
 *********** Second, fill in missing values when possible **********************
 *******************************************************************************

* 1) Breakdown for Net imcome from business

	* Replace gross income if missing and all other components not missing
	* and value would be positive
	replace gincome_fix =  round(nincbus + cgsold + otherexpense_fix,0.000000001) ///
	if missing(gincome_fix) & ///
	!missing(nincbus) & !missing(cgsold_fix) & !missing(otherexpense_fix)
	replace gincome_fix = . if gincome_fix<0
	
	* Replace otherexpense if missing and all other components not missing
	* and value would be positive
	replace otherexpense_fix = round(gincome_fix -cgsold_fix - nincbus,0.000000001) ///
	if missing(otherexpense) & ///
	!missing(nincbus) & !missing(gincome_fix) & !missing(cgsold)
	replace otherexpense_fix = .  if otherexpense_fix<0
	
	* Replace cost of goods sold if missing, all other components not missing,
	* and value would be positive
	replace cgsold_fix =  round(gincome_fix - otherexpense_fix - nincbus,0.000000001) ///
	if missing(cgsold_fix) & ///
	!missing(nincbus) & !missing(gincome_fix) & !missing(otherexpense_fix)
	replace cgsold_fix = . if cgsold_fix<0
	
	* Calculated Net income from business vs reported
	gen double nincbus_calc  = gincome - cgsold - otherexpense
	gen double nincbus_check = gincome_fix - cgsold_fix - otherexpense_fix
	
/*  The fixed sub-item quantities match the reported net income from business */
	* br taxid year gincome cgsold otherexpense nincbus *_fix

* 2) Breakdown for Total domestic commercial net income
	* Several entries of nincsidebus are missing, but total domcomninc is
	* not missing and equals nincbus. This means the missing cases should
	* just be entered as zeros.

	replace nincsidebus_fix = 0 if nincsidebus==. & ///
	!missing(domcomninc) & domcomninc==nincbus
	
* 3) Breakdown for Total commercial net income
	* Similarly here, many entries of foreign commercial net income
	* are missing, when total commercial net income equals just
	* the domestic net income. These missings are just zeros 
	* It's not that the data wasn't reported, it's that the 
	* company probably doesn't have any foreign operations so
	* the field didn't apply.
	
	* Missing foreign income, but other two not missing
	replace forcomninc_fix = totcomninc - domcomninc if ///
	missing(forcomninc) & !missing(totcomninc) & !missing(domcomninc)
	
	*br taxid year totcomninc domcomninc forcomninc_fix if missing(totcomninc)
	
	* Missing foreign net income and total net income, but
	* domestic is not missing. Assume foreign is zero, total
	* is domestic
	replace forcomninc_fix = 0 if forcomninc==. & ///
	missing(totcomninc) & !missing(domcomninc) 

	replace totcomninc_fix = domcomninc + forcomninc_fix if ///
	missing(totcomninc) & !missing(domcomninc)
	
	misstable sum totcomninc_fix forcomninc_fix domcomninc

* 4) Breakdown for Fiscal net income
	*br nincome nincome_a totcomninc ntaxinc totposadj totnegadj facilityinv 
	
	* Missing variables that look like they should be zeros
	* (that is, just didn't apply to taxpayer)
	
	foreach var of varlist ntaxinc totposadj totnegadj facilityinv{
		replace `var'_fix = 0 if `var'==. & ///
		(!missing(nincome) | !missing(nincome_a))
	}

	* Calculate net income using the data and check
	gen double nincome_calc = totcomninc - ntaxinc + totposadj - totnegadj - facilityinv 
	gen double nincome_check = totcomninc - ntaxinc_fix + totposadj_fix - totnegadj_fix - facilityinv_fix 
	
	* Net income from SPT 1771 aligns a lot more with fixed variable
	count if nincome==nincome_calc 	& !missing(nincome)
	count if nincome==nincome_check  	& !missing(nincome)

*********************************************************
* Fix and harmonize main vars: tincome and net income ***
*********************************************************	
	
* 5) Manual fixes to net income 
	
	* Replace net income in main form with net income from
	* attachment when net income in main form is missing
	
	replace nincome_fix = nincome_a if missing(nincome_fix)
	
	* Replace net income with zero if calculation indicates it's zero and data are missing.
	replace nincome_fix = 0 if nincome_check==0 & missing(nincome_fix)

	*** Take stock, summarize variables and manually check remaining outliers ***
	drop *_check *_calc
	
	ds *_fix, v(32)
	
	foreach var of varlist ///
		totcitdue citdue tincome adjforcred nincome comploss ///
		nincbus gincome cgsold otherexpense 	///
		totcomninc nincsidebus    ///
		forcomninc domcomninc  ntaxinc facilityinv ///
		totposadj     totnegadj{
		
		di in yellow "Raw `var'" 
		sum `var' , detail
		
		di in yellow "Clean `var'"
		sum `var'_fix, detail
	}
	
	* Drop old, replace with new
	drop totcitdue citdue tincome adjforcred nincome comploss ///
		nincbus gincome cgsold otherexpense 	///
		totcomninc nincsidebus    ///
		forcomninc domcomninc  ntaxinc facilityinv ///
		totposadj     totnegadj
		 
	renvars *_fix, postdrop(4)	
	
	drop nincome_a

 ******************************************************************
 ************ Finally, check for and drop major outliers **********
 ******************************************************************
	foreach var of varlist totcitdue citdue tincome adjforcred nincome comploss ///
			nincbus gincome cgsold otherexpense 	///
			totcomninc nincsidebus    ///
			forcomninc domcomninc  ntaxinc facilityinv ///
			totposadj     totnegadj{
				
			sum `var', detail
			if `r(p1)'<0{
				egen double p0001`var' = pctile(`var'), p(00.01)
				gen double isbot`var' = (`var' <= p0001`var' & !missing(`var'))
			}
			
			sum `var', detail
			if `r(p99)'>0{
				egen double p9999`var' = pctile(`var'), p(99.99)
				gen double istop`var' = (`var' >= p9999`var' & !missing(`var'))
			}
	}
	
	* Drop taxpayers that are outliers
	egen maxtop = rowmax(istop*)
	egen maxbot = rowmax(isbot*)
	
	bys npwp: egen anymaxtop = max(maxtop)
	bys npwp: egen anymaxbot = max(maxbot)
	
	unique npwp if anymaxtop==1 & evermto==1
	unique npwp if anymaxtop==1 & evermto==0
	
	unique npwp if anymaxbot==1 & evermto==1
	unique npwp if anymaxbot==1 & evermto==0
	
	drop if anymaxtop==1 | anymaxbot==1
	
	drop maxtop maxbot anymax*
	*br
	* Remaining massive outlier across all vars
	drop if npwp==3650495
	
 ********************************************************************************
 ******************** End of detailed SPT 1771 cleaning *************************	
 ********************************************************************************
